@@ -1,3 +1,21 @@
+/*
+ * Copyright 2021 KylinSoft Co., Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "blueeffect.h"
 
 Blueeffect::Blueeffect(QWidget *parent) : QWidget(parent)
@@ -8,7 +26,7 @@ Blueeffect::Blueeffect(QWidget *parent) : QWidget(parent)
     m_svgHandler = new SVGHandler(this);
     m_workLayout = new QHBoxLayout;
 
-    this->setStyleSheet("Blueeffect{background-color:#3D6BE5;border-radius:4px;}");
+    this->setStyleSheet("Blueeffect{background-color:#3790FA;border-radius:4px;}");
     m_textLabel->setStyleSheet("color:#ffffff;background:transparent;");
     m_iconLabel->setStyleSheet("background:transparent;");
     m_iconLabel->setFixedSize(24,24);
@@ -43,8 +61,8 @@ void Blueeffect::startmoive() {
 
 void Blueeffect::stop() {
     m_cCnt = 1;
-    m_iconLabel->setPixmap(m_svgHandler->loadSvg(":/new/image/loading11.svg"));
-    if(m_cTimer->isActive())
+    m_iconLabel->setPixmap(m_svgHandler->loadSvgColor(":/new/image/loading11.svg","white",16));
+    if (m_cTimer->isActive())
         m_cTimer->stop();
     hide();
 }
