@@ -27,6 +27,7 @@
 #include <QFileDialog>
 #include <QPainter>
 #include <QPainterPath>
+#include <QButtonGroup>
 
 /* qt会将glib里的signals成员识别为宏，所以取消该宏
  * 后面如果用到signals时，使用Q_SIGNALS代替即可
@@ -35,15 +36,15 @@
 #undef signals
 #endif
 
-extern "C" {
 #include <glib.h>
 #include <gio/gio.h>
-}
 
 namespace Ui {
 class ChangeFaceDialog;
 }
 
+class QLabel;
+
 class ChangeFaceDialog : public QDialog
 {
     Q_OBJECT
@@ -68,8 +69,15 @@ protected:
 private:
     Ui::ChangeFaceDialog *ui;
 
+    bool QLabelSetText(QLabel *label, QString string);
+
+private:
+    QString selectedFaceIcon;
+
+    QButtonGroup * btnsGroup;
+
 Q_SIGNALS:
-    void face_file_send(QString file, QString username);
+    void face_file_send(QString file);
 };
 
 #endif // CHANGEFACEDIALOG_H
