@@ -23,6 +23,7 @@
 #include <QDialog>
 #include <QPainter>
 #include <QPainterPath>
+#include <QLabel>
 
 namespace Ui {
 class ChangeTypeDialog;
@@ -43,11 +44,13 @@ public:
     void setUsername(QString name);
     void setCurrentAccountTypeLabel(QString aType);
     void setCurrentAccountTypeBtn(int id);
+    bool QLabelSetText(QLabel *label, QString string);
 
-    void forbidenChange(int total);
+    void forbidenChange(int can);
 
 protected:
     void paintEvent(QPaintEvent *);
+    void keyPressEvent(QKeyEvent *);
 
 private:
     Ui::ChangeTypeDialog *ui;
@@ -56,7 +59,7 @@ private:
     bool currentloginstatus;
 
 Q_SIGNALS:
-    void type_send(int type, QString username);
+    void type_send(int type);
 };
 
 #endif // CHANGETYPEDIALOG_H
