@@ -1,3 +1,21 @@
+/*
+ * Copyright (C) 2021 KylinSoft Co., Ltd.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
+ */
 
 
 /* qt会将glib里的signals成员识别为宏，所以取消该宏
@@ -7,7 +25,6 @@
 #undef signals
 #endif
 
-extern "C" {
 #include <glib.h>
 #include <gio/gio.h>
 
@@ -16,8 +33,6 @@ extern "C" {
 #include <errno.h>
 #include <sys/wait.h>
 
-}
-
 #include "run-passwd.h"
 
 /* Buffer size for backend output */
