@@ -26,8 +26,8 @@
 #include <QMessageBox>
 #include <QHBoxLayout>
 #include <QStyledItemDelegate>
-#include "switchbutton.h"
 #include "ukui_custom_style.h"
+#include "SwitchButton/switchbutton.h"
 
 class UkuiMessageBox : public QMessageBox
 {
@@ -52,32 +52,35 @@ private:
     QFrame *m_pLagoutWidget;
     QFrame *m_pAlertSoundSwitchWidget;
     QFrame *m_pAlertSoundVolumeWidget;
-    QFrame *m_pWindowClosedWidget;
+    QFrame *m_pWakeupMusicWidget;
     QFrame *m_pVolumeChangeWidget;
-    QFrame *m_pSettingSoundWidget;
+    QFrame *m_pStartupMusicWidget;
+    QFrame *m_pPoweroffMusicWidget;
 
     QString qss;
     QStyledItemDelegate *itemDelegate;
-    QLabel *m_pSoundEffectLabel;
+    TitleLabel *m_pSoundEffectLabel;
     QLabel *m_pSoundThemeLabel;
     QLabel *m_pShutdownlabel;
     QLabel *m_pLagoutLabel;
     QLabel *m_pAlertSoundSwitchLabel;
     QLabel *m_pAlertSoundLabel;
     QLabel *m_pAlertVolumeLabel;
-    QLabel *m_pWindowClosedLabel;
+    QLabel *m_pWakeupMusicLabel;
     QLabel *m_pVolumeChangeLabel;
-    QLabel *m_pSettingSoundLabel;
+    QLabel *m_pPoweroffMusicLabel;
+    QLabel *m_pStartupMusicLabel;
 
     QComboBox *m_pSoundThemeCombobox;
     QComboBox *m_pAlertSoundCombobox;
     QComboBox *m_pLagoutCombobox;
-    QComboBox *m_pWindowClosedCombobox;
     QComboBox *m_pVolumeChangeCombobox;
-    QComboBox *m_pSettingSoundCombobox;
     QVBoxLayout *m_pSoundLayout;
-    SwitchButton *m_pBootButton;
+    SwitchButton *m_pStartupButton;
+    SwitchButton *m_pPoweroffButton;
+    SwitchButton *m_pLogoutButton;
     SwitchButton *m_pAlertSoundSwitchButton;
+    SwitchButton *m_pWakeupMusicButton;
     UkmediaVolumeSlider *m_pAlertSlider;
     UkuiButtonDrawSvg *m_pAlertIconBtn;
 };
