@@ -67,17 +67,31 @@ UkmediaVolumeSlider::UkmediaVolumeSlider(QWidget *parent,bool needTip)
 
 void UkmediaVolumeSlider::mousePressEvent(QMouseEvent *ev)
 {
-    if (state) {
-        m_pTiplabel->show();
+    int value = 0;
+    int currentX = ev->pos().x();
+    double per = currentX * 1.0 / this->width();
+    if ((this->maximum() - this->minimum()) >= 50) { //减小鼠标点击像素的影响
+        value = qRound(per*(this->maximum() - this->minimum())) + this->minimum();
+        if (value <= (this->maximum() / 2 - this->maximum() / 10 + this->minimum() / 10)) {
+            value = qRound(per*(this->maximum() - this->minimum() - 1)) + this->minimum();
+        } else if (value > (this->maximum() / 2 + this->maximum() / 10 + this->minimum() / 10)) {
+            value = qRound(per*(this->maximum() - this->minimum() + 1)) + this->minimum();
+        } else {
+            value = qRound(per*(this->maximum() - this->minimum())) + this->minimum();
+        }
+    } else {
+        value = qRound(per*(this->maximum() - this->minimum())) + this->minimum();
     }
-    //注意应先调用父类的鼠标点击处理事件，这样可以不影响拖动的情况
+    this->setValue(value);
     QSlider::mousePressEvent(ev);
-    //获取鼠标的位置，这里并不能直接从ev中取值（因为如果是拖动的话，鼠标开始点击的位置没有意义了）
-    double pos = ev->pos().x() / (double)width();
-    setValue(pos *(maximum() - minimum()) + minimum());
-    //向父窗口发送自定义事件event type，这样就可以在父窗口中捕获这个事件进行处理
-    QEvent evEvent(static_cast<QEvent::Type>(QEvent::User + 1));
-    QCoreApplication::sendEvent(parentWidget(), &evEvent);
+}
+void UkmediaVolumeSlider::mouseReleaseEvent(QMouseEvent *e)
+{
+    if(mousePress){
+        Q_EMIT silderReleaseSignal();
+    }
+    mousePress = false;
+    QSlider::mouseReleaseEvent(e);
 }
 
 void UkmediaVolumeSlider::initStyleOption(QStyleOptionSlider *option)
