@@ -25,6 +25,7 @@
 #include <QImage>
 #include <QSlider>
 #include <QLabel>
+#include "Label/titlelabel.h"
 
 static QColor symbolic_color = Qt::gray;
 
@@ -48,11 +49,15 @@ public:
 private:
     UkuiMediaSliderTipLabel *m_pTiplabel;
     bool state = false;
+
+    bool mousePress =false;
 Q_SIGNALS:
-    void silderPressedSignal(int);
+    void silderPressedSignal();
+    void silderReleaseSignal();
 
 protected:
     void mousePressEvent(QMouseEvent *ev);
+    void mouseReleaseEvent(QMouseEvent *e);
     void mouseMoveEvent(QMouseEvent *e)
     {
 //        setCursor(QCursor(Qt::OpenHandCursor));
@@ -83,6 +88,8 @@ protected:
 private:
     QImage mImage;
     QColor mColor;
+
+    bool mousePress = false;
 };
 
 #endif // UKUICUSTOMSTYLE_H
