@@ -1,4 +1,3 @@
-
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
  *
  * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
@@ -25,26 +24,30 @@
 #include <QDebug>
 #include <QtDBus/QDBusConnection>
 #include <QtConcurrent>
+#include <QRadioButton>
 
 #include "SwitchButton/switchbutton.h"
+#include "Label/iconlabel.h"
+#include "myqradiobutton.h"
 #include "cursor/xcursortheme.h"
 #include "../../../shell/customstyle.h"
+#include "../../../shell/utils/utils.h"
 
 // GTK主题
 #define THEME_GTK_SCHEMA "org.mate.interface"
 #define MODE_GTK_KEY     "gtk-theme"
 
 // GTK图标主题
-#define ICON_GTK_KEY    "icon-theme"
+#define ICON_GTK_KEY     "icon-theme"
 
 // QT主题
-#define THEME_QT_SCHEMA "org.ukui.style"
-#define MODE_QT_KEY     "style-name"
-#define THEME_TRAN_KEY  "menu-transparency"
-#define PEONY_TRAN_KEY  "peony-side-bar-transparency"
+#define THEME_QT_SCHEMA  "org.ukui.style"
+#define MODE_QT_KEY      "style-name"
+#define THEME_TRAN_KEY   "menu-transparency"
+#define PEONY_TRAN_KEY   "peony-side-bar-transparency"
 
 // QT图标主题
-#define ICON_QT_KEY     "icon-theme-name"
+#define ICON_QT_KEY      "icon-theme-name"
 
 // 窗口管理器Marco主题
 #define MARCO_SCHEMA    "org.gnome.desktop.wm.preferences"
@@ -64,17 +67,18 @@
 #define PERSONALSIE_TRAN_KEY   "transparency"
 #define PERSONALSIE_BLURRY_KEY "blurry"
 #define PERSONALSIE_EFFECT_KEY "effect"
+#define PERSONALSIE_SAVE_TRAN_KEY "save-transparency"
 
 const QString kDefCursor =           "DMZ-White";
 const QString UbuntuVesionEnhance =  "20.10";
 const QString kXder =                "XRender";
 
 const int transparency = 75;
+//保存关闭特效模式之前的透明度
+int save_trans = 0;
 
 const QStringList effectList {"blur", "kwin4_effect_translucency", "kwin4_effect_maximize", "zoom"};
-const QStringList kIconsList {"blueman", "disk-burner", "firefox", "kylin-video", "kylin-assistant", "kylin-scanner", "kylin-ipmsg"};
-
-const QStringList kExcludeIcon {"ukui-icon-theme-default", "ukui-icon-theme-classical", "ukui-icon-theme-basic"};
+const QStringList kIconsList {"computer.png", "user-trash.png", "system-file-manager.png", "ukui-control-center.png", "kylin-software-center.png", "kylin-video.png", "kylin-assistant.png"};
 
 namespace {
 
@@ -108,15 +112,11 @@ Theme::Theme()
     pluginName = tr("Theme");
     pluginType = PERSONALIZED;
     ui->setupUi(pluginWidget);
-    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
-    ui->iconLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
-    ui->cursorLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
-    ui->effectLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
 
     setupGSettings();
     initSearchText();
 
-    //设置组件
+    // 设置组件
     setupComponent();
     setupSettings();
     initThemeMode();
@@ -128,6 +128,7 @@ Theme::Theme()
 Theme::~Theme()
 {
     delete ui;
+    ui = nullptr;
 }
 
 QString Theme::get_plugin_name() {
@@ -162,6 +163,8 @@ void Theme::initSearchText() {
     ui->perforLabel->setText(tr("Performance mode"));
     //~ contents_path /theme/Transparency
     ui->transparencyLabel->setText(tr("Transparency"));
+    //~ contents_path /theme/Reset to default
+    ui->resetBtn->setText(tr("Reset to default"));
 }
 
 void Theme::setupSettings() {
@@ -169,7 +172,6 @@ void Theme::setupSettings() {
     kwinSettings = new QSettings(filename, QSettings::IniFormat, this);
 
     QStringList keys = kwinSettings->childGroups();
-
     kwinSettings->beginGroup("Plugins");
     bool kwin = kwinSettings->value("blurEnabled", kwin).toBool();
 
@@ -205,21 +207,35 @@ void Theme::setupSettings() {
             ui->transFrame->setVisible(false);
             ui->effectLabel->setVisible(false);
             personliseGsettings->set(PERSONALSIE_EFFECT_KEY, false);
+        } else {
+            ui->lowLabel->setPixmap(QPixmap("://img/plugins/theme/opacitylow.svg"));
+            ui->highlabel->setPixmap(QPixmap("://img/plugins/theme/opacityhigh.svg"));
         }
         kwinSettings->endGroup();
+    }else {
+        ui->lowLabel->setPixmap(QPixmap("://img/plugins/theme/opacitylow.svg"));
+        ui->highlabel->setPixmap(QPixmap("://img/plugins/theme/opacityhigh.svg"));
     }
 }
 
 void Theme::setupComponent() {
 
-    ui->lightButton->setVisible(getSystemVersion());
+    ui->frame_2->setVisible(getSystemVersion());
+    if (!getSystemVersion()) {
+        ui->horizontalSpacer_10->changeSize(0,0);
+    }
+
     //隐藏现阶段不支持功能
     ui->controlLabel->hide();
     ui->controlWidget->hide();
+    ui->verticalSpacer_2->changeSize(0,0);
 
-    ui->defaultButton->setProperty("value", "ukui");
+    ui->defaultButton->setProperty("value", "ukui-default");
+    ui->defaultButton->setStyleSheet("QPushButton{color: palette(base);border-radius: 4px;}");
     ui->lightButton->setProperty("value", "ukui-light");
+    ui->lightButton->setStyleSheet("QPushButton{color: palette(base);border-radius: 4px;}");
     ui->darkButton->setProperty("value", "ukui-dark");
+    ui->darkButton->setStyleSheet("QPushButton{color: palette(base);border-radius: 4px;}");
 
     buildThemeModeBtn(ui->defaultButton, tr("Default"), "default");
     buildThemeModeBtn(ui->lightButton, tr("Light"), "light");
@@ -233,9 +249,6 @@ void Theme::setupComponent() {
         qtSettings->set(THEME_TRAN_KEY, ui->tranSlider->value());
         qtSettings->set(PEONY_TRAN_KEY, ui->tranSlider->value());
     });
-    setupControlTheme();
-//    ui->effectLabel->hide();
-//    ui->effectWidget->hide();
 
     //构建并填充特效开关按钮
     effectSwitchBtn = new SwitchButton(pluginWidget);
@@ -246,30 +259,53 @@ void Theme::setupComponent() {
 }
 
 void Theme::buildThemeModeBtn(QPushButton *button, QString name, QString icon){
-    //设置默认按钮
-
+    // 设置默认按钮
     QVBoxLayout * baseVerLayout = new QVBoxLayout(button);
     baseVerLayout->setSpacing(8);
     baseVerLayout->setMargin(0);
-    QLabel * iconLabel = new QLabel(button);
-    iconLabel->setFixedSize(QSize(176, 105));
+    IconLabel * iconLabel = new IconLabel(button);
+    iconLabel->setObjectName("iconlabel");
+    iconLabel->setFixedSize(QSize(176, 104));
     iconLabel->setScaledContents(true);
+    iconLabel->setAttribute(Qt::WA_DeleteOnClose);
     QString fullicon = QString("://img/plugins/theme/%1.png").arg(icon);
-    iconLabel->setPixmap(QPixmap(fullicon));
+    QPixmap *mpixmap = new QPixmap(fullicon);
+    iconLabel->setPixmap(*mpixmap);
+
+    iconLabel->setSizePolicy(QSizePolicy::Ignored,QSizePolicy::Ignored);
+   // iconLabel->setContentsMargins(3,3,3,3);
 
     QHBoxLayout * bottomHorLayout = new QHBoxLayout;
     bottomHorLayout->setSpacing(8);
     bottomHorLayout->setMargin(0);
-    QLabel * statusLabel = new QLabel(button);
-    statusLabel->setFixedSize(QSize(16, 16));
-    statusLabel->setScaledContents(true);
-
+    MyQRadioButton * statusbtn = new MyQRadioButton(button);
+    statusbtn->setFixedSize(QSize(16, 16));
     QLabel * nameLabel = new QLabel(button);
-    QSizePolicy nameSizePolicy = nameLabel->sizePolicy();
-    nameSizePolicy.setVerticalPolicy(QSizePolicy::Fixed);
-    nameSizePolicy.setHorizontalPolicy(QSizePolicy::Fixed);
-    nameLabel->setSizePolicy(nameSizePolicy);
     nameLabel->setText(name);
+    QPalette pal;
+    QBrush brush = pal.highlight();  //获取window的色值
+    QColor highLightColor = brush.color();
+    QString stringColor = QString("rgba(%1,%2,%3)") //叠加20%白色
+           .arg(highLightColor.red()*0.8 + 255*0.2)
+           .arg(highLightColor.green()*0.8 + 255*0.2)
+           .arg(highLightColor.blue()*0.8 + 255*0.2);
+
+    //触发父对象的鼠标点击信号
+    connect(statusbtn,&MyQRadioButton::clicked,[=](){
+        ui->themeModeBtnGroup->buttonClicked(button);
+        emit button->clicked();
+    });
+
+    //触发父对象的悬浮信号
+    connect(statusbtn,&MyQRadioButton::enterWidget,[=](){
+        emit iconLabel->enterWidget();
+    });
+
+    //触发父对象的未悬浮信号
+    connect(statusbtn,&MyQRadioButton::leaveWidget,[=](){
+        emit iconLabel->leaveWidget();
+    });
+
 
 #if QT_VERSION <= QT_VERSION_CHECK(5, 12, 0)
     connect(ui->themeModeBtnGroup, static_cast<void (QButtonGroup::*)(QAbstractButton *)>(&QButtonGroup::buttonClicked), [=](QAbstractButton * eBtn){
@@ -277,17 +313,42 @@ void Theme::buildThemeModeBtn(QPushButton *button, QString name, QString icon){
     connect(ui->themeModeBtnGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), [=](QAbstractButton * eBtn){
 #endif
         if (eBtn == button) {
-            nameLabel->setStyleSheet("color: #ffffff;");
-            statusLabel->setPixmap(QPixmap("://img/plugins/theme/selected.svg"));
+            statusbtn->setChecked(true);
+            button->setChecked(true);
         }
         else {
-            nameLabel->setStyleSheet("color: palette(windowText);");
-            statusLabel->clear();
+            statusbtn->setChecked(false);
+            button->setChecked(false);
+            emit iconLabel->leaveWidget();
         }
     });
 
+    connect(button,&QPushButton::clicked,[=](){
+        iconLabel->setStyleSheet("border: 2px");
+        iconLabel->setStyleSheet(QString("QLabel#iconlabel{border-radius: 6px;\
+                                            border-width: 2px;border-style: solid;border-color: %1;}").arg(stringColor));
+    });
+
+
+
+    connect(iconLabel,&IconLabel::enterWidget,[=](){
+        if (!button->isChecked()) {
+            iconLabel->setStyleSheet("border: 1px");
+            iconLabel->setStyleSheet(QString("QLabel#iconlabel{border-radius: 6px;\
+                                             border-width: 1px;border-style: solid;border-color: %1;}").arg(stringColor));
+        }
+
+    });
+    connect(iconLabel,&IconLabel::leaveWidget,[=](){
+        if (!button->isChecked()) {
+            iconLabel->setStyleSheet("border: 0px");
+        }
+
+     });
+
     bottomHorLayout->addStretch();
-    bottomHorLayout->addWidget(statusLabel);
+    bottomHorLayout->setContentsMargins(0,16,0,0);
+    bottomHorLayout->addWidget(statusbtn);
     bottomHorLayout->addWidget(nameLabel);
     bottomHorLayout->addStretch();
 
@@ -300,23 +361,31 @@ void Theme::buildThemeModeBtn(QPushButton *button, QString name, QString icon){
 void Theme::initThemeMode() {
     // 获取当前主题
     QString currentThemeMode = qtSettings->get(MODE_QT_KEY).toString();
-    if ("ukui" == currentThemeMode) {
+    if ("ukui-white" == currentThemeMode || "ukui-default" == currentThemeMode) {
         ui->themeModeBtnGroup->buttonClicked(ui->defaultButton);
-    } else if ("ukui-dark" == currentThemeMode){
+        emit ui->defaultButton->clicked();
+    } else if ("ukui-dark" == currentThemeMode || "ukui-black" == currentThemeMode){
         ui->themeModeBtnGroup->buttonClicked(ui->darkButton);
+        emit ui->darkButton->clicked();
     } else {
         ui->themeModeBtnGroup->buttonClicked(ui->lightButton);
+        emit ui->lightButton->clicked();
     }
 
     qApp->setStyle(new InternalStyle("ukui"));
 
-    //监听主题改变
+    // 监听主题改变
     connect(qtSettings, &QGSettings::changed, this, [=](const QString &key) {
         if (key == "styleName") {
-            //获取当前主题
+            // 获取当前主题
             QString currentThemeMode = qtSettings->get(key).toString();
             for (QAbstractButton * button : ui->themeModeBtnGroup->buttons()){
                 QVariant valueVariant = button->property("value");
+                if ("ukui-black" == currentThemeMode) {
+                    currentThemeMode = "ukui-dark";
+                } else if("ukui-white" == currentThemeMode) {
+                    currentThemeMode = "ukui-default";
+                }
                 if (valueVariant.isValid() && valueVariant.toString() == currentThemeMode) {
                     disconnect(ui->themeModeBtnGroup, SIGNAL(buttonClicked(QAbstractButton*)), this, SLOT(themeBtnClickSlot(QAbstractButton*)));
                     button->click();
@@ -352,18 +421,19 @@ void Theme::initThemeMode() {
 }
 
 void Theme::initIconTheme() {
-    //获取当前图标主题(以QT为准，后续可以对比GTK两个值)
+    // 获取当前图标主题(以QT为准，后续可以对比GTK两个值)
     QString currentIconTheme = qtSettings->get(ICON_QT_KEY).toString();
 
-    //构建图标主题Widget Group，方便更新选中/非选中状态
+    // 构建图标主题Widget Group，方便更新选中/非选中状态
     iconThemeWidgetGroup = new WidgetGroup;
     connect(iconThemeWidgetGroup, &WidgetGroup::widgetChanged, [=](ThemeWidget * preWidget, ThemeWidget * curWidget){
-        if (preWidget)
+        if (preWidget) {
             preWidget->setSelectedStatus(false);
+        }
         curWidget->setSelectedStatus(true);
 
         QString value = curWidget->getValue();
-        //设置图标主题
+        // 设置图标主题
         qtSettings->set(ICON_QT_KEY, value);
         gtkSettings->set(ICON_GTK_KEY, value);
     });
@@ -372,22 +442,33 @@ void Theme::initIconTheme() {
     QDir themesDir = QDir(ICONTHEMEPATH);
 
     foreach (QString themedir, themesDir.entryList(QDir::Dirs)) {
-        if (themedir.startsWith("ukui")){
 
+        if ((Utils::isCommunity() && (!themedir.compare("ukui") || !themedir.compare("ukui-classical")))
+                || (!Utils::isCommunity() && themedir.startsWith("ukui-icon-theme-"))) {
             QDir appsDir = QDir(ICONTHEMEPATH + themedir + "/48x48/apps/");
-
-            if (kExcludeIcon.contains(themedir, Qt::CaseInsensitive)) {
+            QDir placesDir = QDir(ICONTHEMEPATH + themedir + "/48x48/places/");
+            QDir devicesDir = QDir(ICONTHEMEPATH + themedir + "/48x48/devices/");
+            if ("ukui-icon-theme-basic" == themedir) {
                 continue;
             }
             appsDir.setFilter(QDir::Files | QDir::NoSymLinks);
-            QStringList appIconsList = appsDir.entryList();
-
+            devicesDir.setFilter(QDir::Files | QDir::NoSymLinks);
+            placesDir.setFilter(QDir::Files | QDir::NoSymLinks);
             QStringList showIconsList;
             for (int i = 0; i < kIconsList.size(); i++) {
-                showIconsList.append(appsDir.path() + "/" + kIconsList.at(i));
+                if (QFile(appsDir.path() + "/" + kIconsList.at(i)).exists()) {
+                    showIconsList.append(appsDir.path() + "/" + kIconsList.at(i));
+                    continue;
+                } else if (QFile(devicesDir.path() + "/" + kIconsList.at(i)).exists()) {
+                    showIconsList.append(devicesDir.path() + "/" + kIconsList.at(i));
+                    continue;
+                } else if (QFile(placesDir.path() + "/" + kIconsList.at(i)).exists()) {
+                    showIconsList.append(placesDir.path() + "/" + kIconsList.at(i));
+                    continue;
+                }
             }
 
-            ThemeWidget * widget = new ThemeWidget(QSize(48, 48), dullTranslation(themedir.section("-", -1, -1, QString::SectionSkipEmpty)), showIconsList);
+            ThemeWidget * widget = new ThemeWidget(QSize(48, 48), dullTranslation(themedir.section("-", -1, -1, QString::SectionSkipEmpty)), showIconsList, pluginWidget);
             widget->setValue(themedir);
 
             // 加入Layout
@@ -424,8 +505,6 @@ void Theme::setupControlTheme(){
         QPushButton * button = new QPushButton(ui->controlWidget);
         button->setFixedSize(QSize(48, 48));
         button->setCheckable(true);
-        QString btnStyle = QString("QPushButton{background: %1; border-radius: 4px;}").arg(color);
-//        button->setStyleSheet(btnStyle);
         colorBtnGroup->addButton(button, colorStringList.indexOf(color));
 
         QVBoxLayout * colorVerLayout = new QVBoxLayout();
@@ -443,12 +522,8 @@ void Theme::setupControlTheme(){
         selectedColorLabel->setSizePolicy(scSizePolicy);
         selectedColorLabel->setScaledContents(true);
         selectedColorLabel->setPixmap(QPixmap("://img/plugins/theme/selected.png"));
-        //初始化选中图标状态
+        // 初始化选中图标状态
         selectedColorLabel->setVisible(button->isChecked());
-//        connect(colorBtnGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this,[=]{
-//            selectedColorLabel->setVisible(button->isChecked());
-//            //设置控件主题
-//        });
 
         colorHorLayout->addStretch();
         colorHorLayout->addWidget(selectedColorLabel);
@@ -465,43 +540,24 @@ void Theme::initCursorTheme(){
 
     QStringList cursorThemes = _getSystemCursorThemes();
 
-    //获取当前指针主题
+    // 获取当前指针主题
     QString currentCursorTheme;
     currentCursorTheme = curSettings->get(CURSOR_THEME_KEY).toString();
 
     cursorThemeWidgetGroup = new WidgetGroup(this);
     connect(cursorThemeWidgetGroup, &WidgetGroup::widgetChanged, [=](ThemeWidget * preWidget, ThemeWidget * curWidget){
-        if (preWidget)
-            preWidget->setSelectedStatus(false);
+        if (preWidget) {
+             preWidget->setSelectedStatus(false);
+        }
         curWidget->setSelectedStatus(true);
 
         QString value = curWidget->getValue();
-        //设置光标主题
+        // 设置光标主题
         curSettings->set(CURSOR_THEME_KEY, value);
-
-#if QT_VERSION <= QT_VERSION_CHECK(5,12,0)
-
-#else
-        QString filename = QDir::homePath() + "/.config/kcminputrc";
-        QSettings *mouseSettings = new QSettings(filename, QSettings::IniFormat);
-
-        mouseSettings->beginGroup("Mouse");
-        mouseSettings->setValue("cursorTheme", value);
-        mouseSettings->endGroup();
-
-        delete mouseSettings;
-
-        QDBusMessage message = QDBusMessage::createSignal("/KGlobalSettings", "org.kde.KGlobalSettings", "notifyChange");
-        QList<QVariant> args;
-        args.append(5);
-        args.append(0);
-        message.setArguments(args);
-        QDBusConnection::sessionBus().send(message);
-#endif
+        kwinCursorSlot(value);
     });
 
     for (QString cursor : cursorThemes){
-
         QList<QPixmap> cursorVec;
         QString path = CURSORS_THEMES_PATH + cursor;
         XCursorTheme *cursorTheme = new XCursorTheme(path);
@@ -512,13 +568,13 @@ void Theme::initCursorTheme(){
             cursorVec.append(QPixmap::fromImage(image));
         }
 
-        ThemeWidget * widget  = new ThemeWidget(QSize(24, 24), cursor, cursorVec);
+        ThemeWidget * widget  = new ThemeWidget(QSize(24, 24), dullCursorTranslation(cursor), cursorVec, pluginWidget);
         widget->setValue(cursor);
 
-        //加入Layout
+        // 加入Layout
         ui->cursorVerLayout->addWidget(widget);
 
-        //加入WidgetGround实现获取点击前Widget
+        // 加入WidgetGround实现获取点击前Widget
         cursorThemeWidgetGroup->addWidget(widget);
 
         //初始化指针主题选中界面
@@ -531,23 +587,21 @@ void Theme::initCursorTheme(){
     }
 }
 
-void Theme::initEffectSettings() {
-
-}
-
 void Theme::initConnection() {
 
     connect(ui->resetBtn, &QPushButton::clicked, this, &Theme::resetBtnClickSlot);
 
     connect(effectSwitchBtn, &SwitchButton::checkedChanged, [this](bool checked) {
         if (!checked) {
+            save_trans = static_cast<int>(personliseGsettings->get(PERSONALSIE_TRAN_KEY).toDouble() * 100.0);
+            personliseGsettings->set(PERSONALSIE_SAVE_TRAN_KEY, save_trans);
             personliseGsettings->set(PERSONALSIE_TRAN_KEY, 1.0);
             qtSettings->set(THEME_TRAN_KEY, 100);
             qtSettings->set(PEONY_TRAN_KEY, 100);
             ui->tranSlider->setValue(100);
         } else {
-            ui->lowLabel->setPixmap(QPixmap("://img/plugins/theme/opacitylow.svg"));
-            ui->highlabel->setPixmap(QPixmap("://img/plugins/theme/opacityhigh.svg"));
+            save_trans = personliseGsettings->get(PERSONALSIE_SAVE_TRAN_KEY).toInt();
+            ui->tranSlider->setValue(save_trans);
         }
         // 提供给外部监听特效接口
         personliseGsettings->set(PERSONALSIE_EFFECT_KEY, checked);
@@ -555,14 +609,6 @@ void Theme::initConnection() {
         ui->transFrame->setVisible(checked);
         writeKwinSettings(checked, currentThemeMode, true);
     });
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-    ui->transFrame->setVisible(false);
-    ui->effectFrame->setVisible(false);
-    ui->effectLabel->setVisible(false);
-#else
-
-#endif
 }
 
 QStringList Theme::_getSystemCursorThemes() {
@@ -573,7 +619,6 @@ QStringList Theme::_getSystemCursorThemes() {
         foreach (QString dirname, themesDir.entryList(QDir::Dirs)){
             if (dirname == "." || dirname == "..")
                 continue;
-//            QString fullpath(CURSORS_THEMES_PATH + dirname);
             QDir themeDir(CURSORS_THEMES_PATH + dirname + "/cursors/");
             if (themeDir.exists())
                 themes.append(dirname);
@@ -629,43 +674,88 @@ void Theme::setupGSettings() {
     const QByteArray iid(CURSOR_THEME_SCHEMA);
     const QByteArray iiid(PERSONALSIE_SCHEMA);
     gtkSettings = new QGSettings(id, QByteArray(), this);
-    qtSettings = new QGSettings(idd, QByteArray(), this);
+    qtSettings  = new QGSettings(idd, QByteArray(), this);
     curSettings = new QGSettings(iid, QByteArray(), this);
     personliseGsettings = new QGSettings(iiid, QByteArray(), this);
 }
 
+void Theme::kwinCursorSlot(QString value) {
+
+    QString filename = QDir::homePath() + "/.config/kcminputrc";
+    QSettings *mouseSettings = new QSettings(filename, QSettings::IniFormat);
+
+    mouseSettings->beginGroup("Mouse");
+    mouseSettings->setValue("cursorTheme", value);
+    mouseSettings->endGroup();
+
+    delete mouseSettings;
+    mouseSettings = nullptr;
+
+    QDBusMessage message = QDBusMessage::createSignal("/KGlobalSettings", "org.kde.KGlobalSettings", "notifyChange");
+    QList<QVariant> args;
+    args.append(5);
+    args.append(0);
+    message.setArguments(args);
+    QDBusConnection::sessionBus().send(message);
+}
+
+QString Theme::dullCursorTranslation(QString str) {
+    if (!QString::compare(str, "blue-crystal")){
+        return QObject::tr("blue-crystal");
+    } else if (!QString::compare(str, "dark-sense")) {
+        return QObject::tr("dark-sense");
+    } else if (!QString::compare(str, "DMZ-Black")) {
+        return QObject::tr("DMZ-Black");
+    } else if (!QString::compare(str, "DMZ-White")) {
+        return QObject::tr("DMZ-White");
+    } else {
+        return str;
+    }
+}
+
+QString Theme::getCursorName() {
+   return curSettings->get(CURSOR_THEME_KEY).toString();
+}
+
 QString Theme::dullTranslation(QString str) {
     if (!QString::compare(str, "basic")){
         return QObject::tr("basic");
-    } else if (!QString::compare(str, "classical")){
+    } else if (!QString::compare(str, "classical")) {
         return QObject::tr("classical");
-    } else if (!QString::compare(str, "default")){
+    } else if (!QString::compare(str, "default")) {
         return QObject::tr("default");
+    } else if (!QString::compare(str, "fashion")) {
+        return QObject::tr("fashion");
     } else {
         return QObject::tr("default");
     }
 }
 
-// reset all of themes, include cursor, icon,and etc...
+// 重置设置
 void Theme::resetBtnClickSlot() {
 
     emit ui->themeModeBtnGroup->buttonClicked(ui->defaultButton);
 
-    // reset cursor default theme
+    // 重置光标主题
     curSettings->reset(CURSOR_THEME_KEY);
     QString cursorTheme = kDefCursor;
-    QString defaultCursor = curSettings->get(CURSOR_THEME_KEY).toString();
+    QString defaultCursor = getCursorName();
     if (defaultCursor.isEmpty()) {
         curSettings->set(CURSOR_THEME_KEY, kDefCursor);
     } else {
         cursorTheme = defaultCursor;
     }
+    kwinCursorSlot(cursorTheme);
 
-    // reset icon default theme
     qtSettings->reset(ICON_QT_KEY);
 
     if (ui->effectFrame->isVisible()) {
         effectSwitchBtn->setChecked(true);
+        qtSettings->reset(THEME_TRAN_KEY);
+        qtSettings->reset(PEONY_TRAN_KEY);
+        gtkSettings->reset(ICON_GTK_KEY);
+        personliseGsettings->reset(PERSONALSIE_TRAN_KEY);
+        ui->tranSlider->setValue(transparency);
     }
 
     QString icoName = qtSettings->get(ICON_QT_KEY).toString();
@@ -728,12 +818,16 @@ void Theme::themeBtnClickSlot(QAbstractButton *button) {
      QString themeMode = button->property("value").toString();
      QString currentThemeMode = qtSettings->get(MODE_QT_KEY).toString();
 
-     if (QString::compare(currentThemeMode, themeMode)) {
-         gtkSettings->set(MODE_GTK_KEY, themeMode);
+     if (QString::compare(currentThemeMode, themeMode)){
+         QString tmpMode;
+         if ("ukui-dark" == themeMode) {
+             tmpMode = "ukui-black";
+         } else {
+             tmpMode = "ukui-white";
+         }
+         gtkSettings->set(MODE_GTK_KEY, tmpMode);
 
-         QtConcurrent::run([=](){
-             qtSettings->set(MODE_QT_KEY, themeMode);
-         });
+         qtSettings->set(MODE_QT_KEY, themeMode);
      }
 }
 
