@@ -27,13 +27,15 @@
 #include <QDebug>
 #include <QDesktopServices>
 #include <QProcess>
+#include <QFileInfo>
+#include <QFileSystemWatcher>
 
 const QString kylinUrl = "https://www.ubuntukylin.com/wallpaper.html";
 
 enum{
-    PICTURE, //图片背景
-    COLOR, //纯色背景
-    SLIDESHOW //幻灯片背景
+    PICTURE,   // 图片背景
+    COLOR,     // 纯色背景
+    SLIDESHOW  // 幻灯片背景
 };
 
 #define ITEMWIDTH 182
@@ -46,16 +48,16 @@ Wallpaper::Wallpaper() : mFirstLoad(true)
 {
     pluginName = tr("Background");
     pluginType = PERSONALIZED;
+    prePicUnit = nullptr;
 }
 
 Wallpaper::~Wallpaper()
 {
     if (!mFirstLoad) {
         delete ui;
-        if (settingsCreate){
-            delete bgsettings;
-        }
+        ui = nullptr;
         delete xmlhandleObj;
+        xmlhandleObj = nullptr;
     }
 }
 
@@ -75,22 +77,21 @@ QWidget *Wallpaper::get_plugin_ui() {
         pluginWidget = new QWidget;
         pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
         ui->setupUi(pluginWidget);
-        ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
 
         settingsCreate = false;
         initSearchText();
-        //初始化控件
+        // 初始化控件
         setupComponent();
-        //初始化gsettings
+        // 初始化gsettings
         const QByteArray id(BACKGROUND);
         if (QGSettings::isSchemaInstalled(id)){
             settingsCreate = true;
 
-            bgsettings = new QGSettings(id);
+            bgsettings = new QGSettings(id, QByteArray(), this);
             setupConnect();
             initBgFormStatus();
         }
-        //构建xmlhandle对象
+        // 构建xmlhandle对象
         xmlhandleObj = new XmlHandle();
     }
     return pluginWidget;
@@ -117,7 +118,13 @@ void Wallpaper::initSearchText() {
 
 void Wallpaper::setupComponent(){
 
+    QString name = qgetenv("USER");
+    if (name.isEmpty()) {
+        name = qgetenv("USERNAME");
+    }
 
+    QString lockfilename = "/var/lib/lightdm-data/" + name + "/ukui-greeter.conf";
+    mLockLoginSettings = new QSettings(lockfilename, QSettings::IniFormat, this);
 
     // 背景形式
     QStringList formList;
@@ -138,12 +145,25 @@ void Wallpaper::setupComponent(){
     colWgt->setObjectName("colWgt");
     colWgt->setMinimumSize(QSize(580, 50));
     colWgt->setMaximumSize(QSize(960, 50));
-    colWgt->setStyleSheet("HoverWidget#colWgt{background: palette(button); border-radius: 4px;}HoverWidget:hover:!pressed#colWgt{background: #3D6BE5; border-radius: 4px;}");
+    QPalette pal;
+    QBrush brush = pal.highlight();  //获取window的色值
+    QColor highLightColor = brush.color();
+    QString stringColor = QString("rgba(%1,%2,%3)") //叠加20%白色
+           .arg(highLightColor.red()*0.8 + 255*0.2)
+           .arg(highLightColor.green()*0.8 + 255*0.2)
+           .arg(highLightColor.blue()*0.8 + 255*0.2);
+
+    colWgt->setStyleSheet(QString("HoverWidget#colWgt{background: palette(button);\
+                                   border-radius: 4px;}\
+                                   HoverWidget:hover:!pressed#colWgt{background: %1;  \
+                                   border-radius: 4px;}").arg(stringColor));
     QHBoxLayout *addLyt = new QHBoxLayout;
     QLabel * iconLabel = new QLabel();
     QLabel * textLabel = new QLabel(tr("Custom color"));
     QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "black", 12);
     iconLabel->setPixmap(pixgray);
+    iconLabel->setProperty("useIconHighlightEffect", true);
+    iconLabel->setProperty("iconHighlightEffectMode", 1);
     addLyt->addWidget(iconLabel);
     addLyt->addWidget(textLabel);
     addLyt->addStretch();
@@ -151,16 +171,20 @@ void Wallpaper::setupComponent(){
     ui->horizontalLayout_7->addWidget(colWgt);
 
     // 悬浮改变Widget状态
-    connect(colWgt, &HoverWidget::enterWidget, this, [=](QString mname){
-        Q_UNUSED(mname);
+    connect(colWgt, &HoverWidget::enterWidget, this, [=](){
+
+        iconLabel->setProperty("useIconHighlightEffect", false);
+        iconLabel->setProperty("iconHighlightEffectMode", 0);
         QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "white", 12);
         iconLabel->setPixmap(pixgray);
-        textLabel->setStyleSheet("color: palette(base);");
-
+        textLabel->setStyleSheet("color: white;");
     });
+
     // 还原状态
-    connect(colWgt, &HoverWidget::leaveWidget, this, [=](QString mname){
-        Q_UNUSED(mname);
+    connect(colWgt, &HoverWidget::leaveWidget, this, [=](){
+
+        iconLabel->setProperty("useIconHighlightEffect", true);
+        iconLabel->setProperty("iconHighlightEffectMode", 1);
         QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "black", 12);
         iconLabel->setPixmap(pixgray);
         textLabel->setStyleSheet("color: palette(windowText);");
@@ -168,25 +192,45 @@ void Wallpaper::setupComponent(){
     // 打开自定义颜色面板
     connect(colWgt, &HoverWidget::widgetClicked,[=](QString mname){
         Q_UNUSED(mname);
-        colordialog = new ColorDialog();
+        colordialog = new ColorDialog(pluginWidget);
         connect(colordialog,&ColorDialog::colorSelected,this,&Wallpaper::colorSelectedSlot);
         colordialog->exec();
 
     });
-
 }
 
 void Wallpaper::setupConnect(){
     //使用线程构建本地壁纸文件；获取壁纸压缩QPixmap
     pThread = new QThread;
     pObject = new WorkerObject;
+    QString bgFileName = bgsettings->get(FILENAME).toString();
     connect(pObject, &WorkerObject::pixmapGenerate, this, [=](QPixmap pixmap, QString filename){
         PictureUnit * picUnit = new PictureUnit;
         picUnit->setPixmap(pixmap);
         picUnit->setFilenameText(filename);
+        if (bgFileName == filename) {
+            if (prePicUnit != nullptr) {
+                prePicUnit->changeClickedFlag(false);
+                prePicUnit->setStyleSheet("border-width: 0px;");
+            }
+            picUnit->changeClickedFlag(true);
+            prePicUnit = picUnit;
+            picUnit->setFrameShape(QFrame::Box);
+            picUnit->setStyleSheet(picUnit->clickedStyleSheet);
+        }
+
         connect(picUnit, &PictureUnit::clicked, [=](QString fn){
-//            ui->previewLabel->setPixmap(pixmap.scaled(ui->previewLabel->size()));
+            if(prePicUnit != nullptr)
+            {
+                prePicUnit->changeClickedFlag(false);
+                prePicUnit->setStyleSheet("border-width: 0px;");
+            }
+            picUnit->changeClickedFlag(true);
+            prePicUnit = picUnit;
+            picUnit->setFrameShape(QFrame::Box);
+            picUnit->setStyleSheet(picUnit->clickedStyleSheet);
             bgsettings->set(FILENAME, fn);
+            setLockBackground("");
             ui->previewStackedWidget->setCurrentIndex(PICTURE);
         });
 
@@ -215,13 +259,13 @@ void Wallpaper::setupConnect(){
         showLocalWpDialog();
     });
 
-
     connect(ui->browserOnlinewpBtn, &QPushButton::clicked, [=]{
         QDesktopServices::openUrl(QUrl(kylinUrl));
     });
+
     connect(ui->resetBtn, SIGNAL(clicked(bool)), this, SLOT(resetDefaultWallpaperSlot()));
 
-    ///纯色背景
+    // 纯色背景
     QStringList colors;
 
     colors << "#2d7d9a" << "#018574" << "#107c10" << "#10893e" << "#038387" << "#486860" << "#525e54" << "#7e735f" << "#4c4a48" << "#000000";
@@ -241,6 +285,7 @@ void Wallpaper::setupConnect(){
             bgsettings->set(FILENAME, "");
             bgsettings->set(PRIMARY, QVariant(color));
             bgsettings->set(SECONDARY, QVariant(color));
+            setLockBackground(color);
 
             ui->previewStackedWidget->setCurrentIndex(COLOR);
         });
@@ -315,7 +360,7 @@ int Wallpaper::_getCurrentBgForm(){
 
     int current = 0;
 
-    //设置当前背景形式
+    // 设置当前背景形式
     if (filename.isEmpty()){
         current = COLOR;
     } else if (filename.endsWith("xml")){
@@ -333,9 +378,9 @@ void Wallpaper::initBgFormStatus(){
 
     int currentIndex = _getCurrentBgForm();
     //设置当前背景形式
-    ui->formComBox->blockSignals(true);
+   // ui->formComBox->blockSignals(true);
     ui->formComBox->setCurrentIndex(currentIndex);
-    ui->formComBox->blockSignals(false);
+   // ui->formComBox->blockSignals(false);
     ui->substackedWidget->setCurrentIndex(currentIndex);
     ui->previewStackedWidget->setCurrentIndex(currentIndex);
 
@@ -343,29 +388,30 @@ void Wallpaper::initBgFormStatus(){
     showComponent(currentIndex);
 }
 
-void Wallpaper::showComponent(int index){
-    if (PICTURE == index){ //图片
-//        ui->picOptionsComBox->show();
-//        ui->picOptionsLabel->show();
-    } else if (COLOR == index){ //纯色
-//        ui->picOptionsComBox->hide();
-//        ui->picOptionsLabel->hide();
-    } else { //幻灯片
+void Wallpaper::showComponent(int index) {
+    Q_UNUSED(index);
+}
 
-    }
+void Wallpaper::setLockBackground(QString bg) {
+    mLockLoginSettings->beginGroup("greeter");
+    mLockLoginSettings->setValue("color", bg);
+    mLockLoginSettings->endGroup();
 }
 
 void Wallpaper::initPreviewStatus(){
-    //设置图片背景的预览效果
+    // 设置图片背景的预览效果
     QString filename = bgsettings->get(FILENAME).toString();
-//    qDebug()<<"preview pic is---------->"<<filename<<endl;
-
-    QByteArray ba = filename.toLatin1();
-//    if (g_file_test(ba.data(), G_FILE_TEST_EXISTS)){
+    QFileInfo fileinfo = QFileInfo(filename);
+    if(fileinfo.suffix() == "dib")
+    {
+        QFile::copy(filename,".TEMP.bmp");
+        ui->previewLabel->setPixmap(QPixmap(".TEMP.bmp").scaled(ui->previewLabel->size()));
+    }
+    else
+    {
         ui->previewLabel->setPixmap(QPixmap(filename).scaled(ui->previewLabel->size()));
-//    }
-
-    //设置纯色背景的预览效果
+    }
+    // 设置纯色背景的预览效果
     QString color = bgsettings->get(PRIMARY).toString();
     if (!color.isEmpty()){
         QString widgetQss = QString("QWidget{background: %1;}").arg(color);
@@ -373,7 +419,7 @@ void Wallpaper::initPreviewStatus(){
     }
 }
 
-//自定义颜色面板选定颜色
+// 自定义颜色面板选定颜色
 void Wallpaper::colorSelectedSlot(QColor color){
     qDebug() << "colorSelectedSlot" << color << color.name();
 
@@ -383,36 +429,17 @@ void Wallpaper::colorSelectedSlot(QColor color){
     // 设置系统纯色背景
     bgsettings->set(FILENAME, "");
     bgsettings->set(PRIMARY, QVariant(color.name()));
+    setLockBackground(color.name());
 
     ui->previewStackedWidget->setCurrentIndex(COLOR);
 }
 
 void Wallpaper::wpOptionsChangedSlot(QString op){
-    //获取当前选中的壁纸
-//    QListWidgetItem * currentitem = ui->listWidget->currentItem();
-//    QString filename = currentitem->data(Qt::UserRole).toString();
-
-
-    //更新xml数据
-//    if (wallpaperinfosMap.contains(filename)){
-//        wallpaperinfosMap[filename]["options"] = op;
-//    }
-
+    Q_UNUSED(op)
     //将改动保存至文件
     xmlhandleObj->xmlUpdate(wallpaperinfosMap);
 }
 
-void Wallpaper::setlistview(){
-    //初始化listview
-//    ui->listView->setFocusPolicy(Qt::NoFocus);
-//    ui->listView->setAutoFillBackground(true);
-//    ui->listView->setIconSize(QSize(160, 100));
-//    ui->listView->setResizeMode(QListView::Adjust);
-//    ui->listView->setModel(&wpListModel);
-//    ui->listView->setViewMode(QListView::IconMode);
-//    ui->listView->setSpacing(5);
-}
-
 void Wallpaper::setModeldata(){
     QMap<QString, QMap<QString, QString> >::iterator iters = wallpaperinfosMap.begin();
     for (int row = 0; iters != wallpaperinfosMap.end(); iters++, row++){
@@ -442,12 +469,46 @@ void Wallpaper::resetDefaultWallpaperSlot(){
     g_object_unref(wpgsettings);
 
     bgsettings->set(FILENAME, QVariant(QString(dwp)));
+    setClickedPic(QString(dwp));
 }
 
 void Wallpaper::showLocalWpDialog(){
     QStringList filters;
     filters<<tr("Wallpaper files(*.jpg *.jpeg *.bmp *.dib *.png *.jfif *.jpe *.gif *.tif *.tiff *.wdp)")<<tr("allFiles(*.*)");
-    QFileDialog fd;
+    QFileDialog fd(pluginWidget);
+    QList<QUrl> usb_list = fd.sidebarUrls();
+    int sidebarNum = 8;// 最大添加U盘数，可以自己定义
+    QString home_path = QDir::homePath().section("/", -1, -1);
+    QString mnt = "/media/" + home_path + "/";
+    QDir mntDir(mnt);
+    mntDir.setFilter(QDir::Dirs | QDir::NoDotAndDotDot);
+    QFileInfoList file_list = mntDir.entryInfoList();
+    QList<QUrl> mntUrlList;
+    for (int i = 0; i < sidebarNum && i < file_list.size(); ++i) {
+        QFileInfo fi = file_list.at(i);
+        mntUrlList << QUrl("file://" + fi.filePath());
+    }
+
+    QFileSystemWatcher m_fileSystemWatcher(&fd);
+    m_fileSystemWatcher.addPath("/media/" + home_path + "/");
+    connect(&m_fileSystemWatcher, &QFileSystemWatcher::directoryChanged, &fd,
+            [=, &sidebarNum, &mntUrlList, &usb_list, &fd](const QString path) {
+        QDir m_wmntDir(path);
+        m_wmntDir.setFilter(QDir::Dirs | QDir::NoDotAndDotDot);
+        QFileInfoList m_wfilist = m_wmntDir.entryInfoList();
+        mntUrlList.clear();
+        for (int i = 0; i < sidebarNum && i < m_wfilist.size(); ++i) {
+            QFileInfo m_fi = m_wfilist.at(i);
+            mntUrlList << QUrl("file://" + m_fi.filePath());
+        }
+        fd.setSidebarUrls(usb_list + mntUrlList);
+        fd.update();
+    });
+
+    connect(&fd, &QFileDialog::finished, &fd, [=, &usb_list, &fd]() {
+        fd.setSidebarUrls(usb_list);
+    });
+
     fd.setDirectory(QString(const_cast<char *>(g_get_user_special_dir(G_USER_DIRECTORY_PICTURES))));
     fd.setAcceptMode(QFileDialog::AcceptOpen);
     fd.setViewMode(QFileDialog::List);
@@ -460,6 +521,8 @@ void Wallpaper::showLocalWpDialog(){
     fd.setLabelText(QFileDialog::FileType, tr("FileType: "));
     fd.setLabelText(QFileDialog::Reject, tr("Cancel"));
 
+    fd.setSidebarUrls(usb_list + mntUrlList);
+
     if (fd.exec() != QDialog::Accepted)
         return;
     QString selectedfile;
@@ -477,16 +540,17 @@ void Wallpaper::showLocalWpDialog(){
     QString bgfile = "/tmp/" + fileRes.at(fileRes.length() - 1);
 
     // TODO: chinese and space support
-//    if (g_file_test(selectedfile.toLatin1().data(), G_FILE_TEST_EXISTS)) {
     bgsettings->set(FILENAME, selectedfile);
-//    } else {
-//        bgsettings->reset(FILENAME);
-//    }
+    if (prePicUnit != nullptr) {  //去掉选定标记
+        prePicUnit->changeClickedFlag(false);
+        prePicUnit->setStyleSheet("border-width: 0px;");
+    }
 }
 
 void Wallpaper::add_custom_wallpaper(){
     QString filters = "Wallpaper files(*.png *.jpg)";
-    QFileDialog fd;
+    QFileDialog fd(pluginWidget);
+
     fd.setDirectory(QString(const_cast<char *>(g_get_user_special_dir(G_USER_DIRECTORY_PICTURES))));
     fd.setAcceptMode(QFileDialog::AcceptOpen);
     fd.setViewMode(QFileDialog::List);
@@ -499,20 +563,13 @@ void Wallpaper::add_custom_wallpaper(){
     fd.setLabelText(QFileDialog::FileType, tr("FileType: "));
     fd.setLabelText(QFileDialog::Reject, tr("Cancel"));
 
-    if (fd.exec() != QDialog::Accepted)
-        return;
 
     QString selectedfile;
     selectedfile = fd.selectedFiles().first();
 
-    QSize IMAGE_SIZE(160, 120);
-    QPixmap pixmap = QPixmap(selectedfile).scaled(IMAGE_SIZE);
-//    append_item(pixmap, selectedfile);
-
     if (wallpaperinfosMap.contains(selectedfile)){
         wallpaperinfosMap[selectedfile]["deleted"] = "false";
-    }
-    else{
+    } else {
         QMap<QString, QString> tmpinfo;
         tmpinfo.insert("artist", "(none)");
         tmpinfo.insert("deleted", "false");
@@ -526,32 +583,26 @@ void Wallpaper::add_custom_wallpaper(){
 
     }
     xmlhandleObj->xmlUpdate(wallpaperinfosMap);
-
-    if (picWpItemMap.contains(selectedfile)){
-//        ui->listWidget->setCurrentItem(picWpItemMap.find(selectedfile).value());
-    }
-
 }
 
 void Wallpaper::del_wallpaper(){
-    //获取当前选中的壁纸
-//    QListWidgetItem * currentitem = ui->listWidget->currentItem();
-//    QString filename = currentitem->data(Qt::UserRole).toString();
-
-    //更新xml数据
-//    if (wallpaperinfosMap.contains(filename)){
-//        wallpaperinfosMap[filename]["deleted"] = "true";
-
-//        int row = ui->listWidget->row(currentitem);
-
-//        int nextrow = ui->listWidget->count() - 1 - row ? row + 1 : row - 1;
-
-//        ui->listWidget->setCurrentItem(ui->listWidget->item(nextrow));
-
-//        ui->listWidget->takeItem(row);
-
-//    }
-
-//    将改动保存至文件
+    // 将改动保存至文件
     xmlhandleObj->xmlUpdate(wallpaperinfosMap);
 }
+
+void Wallpaper::setClickedPic(QString fileName) {
+    for (int i = picFlowLayout->count() - 1; i >= 0; --i) { 
+        QLayoutItem *it      = picFlowLayout->itemAt(i);
+        PictureUnit *picUnit = static_cast<PictureUnit*>(it->widget());
+        if (fileName == picUnit->filenameText()) {
+            if (prePicUnit != nullptr) {
+                prePicUnit->changeClickedFlag(false);
+                prePicUnit->setStyleSheet("border-width: 0px;");
+            }
+            picUnit->changeClickedFlag(true);
+            prePicUnit = picUnit;
+            picUnit->setFrameShape(QFrame::Box);
+            picUnit->setStyleSheet(picUnit->clickedStyleSheet);
+        }
+    }
+}
