@@ -33,26 +33,17 @@
 
 #define DESKTOPPATH "/usr/share/applications/"
 
-DefaultApp::DefaultApp() {
+DefaultApp::DefaultApp() : mFirstLoad(true)
+{
     pluginName = tr("Default App");
     pluginType = SYSTEM;
-    ui = new Ui::DefaultAppWindow;
-    pluginWidget = new QWidget;
-    pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
-    ui->setupUi(pluginWidget);
-
-    isCloudEmitted = false;
-
-    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
-
-    initUI();
-    connectToServer();
-
-    connect(ui->ResetBtn, SIGNAL(clicked(bool)), this, SLOT(resetDefaultApp()));
 }
 
 DefaultApp::~DefaultApp() {
-    delete ui;
+    if (!mFirstLoad) {
+        delete ui;
+        ui = nullptr;
+    }
 }
 
 QString DefaultApp::get_plugin_name() {
@@ -64,6 +55,26 @@ int DefaultApp::get_plugin_type() {
 }
 
 QWidget *DefaultApp::get_plugin_ui() {
+    if (mFirstLoad) {
+        mFirstLoad = false;
+        ui = new Ui::DefaultAppWindow;
+        pluginWidget = new QWidget;
+        pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
+        ui->setupUi(pluginWidget);
+
+        mDefaultString = tr("No program available");
+        ui->titleLabel->setStyleSheet("QLabel{color: palette(windowText);}");
+        initUI();
+        initSlots();
+        connectToServer();
+
+#ifdef __sw_64__
+        ui->ResetBtn->show();
+#else
+        ui->ResetBtn->hide();
+#endif
+        connect(ui->ResetBtn, SIGNAL(clicked(bool)), this, SLOT(resetDefaultApp()));
+    }
     return pluginWidget;
 }
 
@@ -76,222 +87,37 @@ const QString DefaultApp::name() const {
     return QStringLiteral("defaultapp");
 }
 
+void DefaultApp::initSlots() {
+    connect(ui->browserComBoBox, static_cast<void (QComboBox::*)(int )> (&QComboBox::currentIndexChanged), this, &DefaultApp::browserComBoBox_changed_cb);
+    connect(ui->mailComBoBox, static_cast<void (QComboBox::*)(int )> (&QComboBox::currentIndexChanged), this, &DefaultApp::mailComBoBox_changed_cb);
+    connect(ui->imageComBoBox, static_cast<void (QComboBox::*)(int )> (&QComboBox::currentIndexChanged), this, &DefaultApp::imageComBoBox_changed_cb);
+    connect(ui->audioComBoBox, static_cast<void (QComboBox::*)(int )> (&QComboBox::currentIndexChanged), this, &DefaultApp::audioComBoBox_changed_cb);
+    connect(ui->videoComBoBox, static_cast<void (QComboBox::*)(int )> (&QComboBox::currentIndexChanged), this, &DefaultApp::videoComBoBox_changed_cb);
+    connect(ui->textComBoBox, static_cast<void (QComboBox::*)(int )> (&QComboBox::currentIndexChanged), this, &DefaultApp::textComBoBox_changed_cb);
+}
+
 void DefaultApp::initUI() {
 
-    connect(this,&DefaultApp::appInitDone,this,[=](int index, const QString &type) {
-        if (type == BROWSERTYPE) {
-            ui->browserComBoBox->setCurrentIndex(index);
-            browserComBoBox_changed_cb(index);
-            connect(ui->browserComBoBox, static_cast<void (QComboBox::*)(int )> (&QComboBox::currentIndexChanged), this, &DefaultApp::browserComBoBox_changed_cb);
+    // 若默认应用被卸载，系统会自动设置某个其它应用为默认应用，若不存在其它应用，则显示"无可用程序"
 
-        } else if(type == MAILTYPE) {
-            ui->mailComBoBox->setCurrentIndex(index);
-            mailComBoBox_changed_cb(index);
-            connect(ui->mailComBoBox, static_cast<void (QComboBox::*)(int )> (&QComboBox::currentIndexChanged), this, &DefaultApp::mailComBoBox_changed_cb);
+    // BROWSER
+    initDefaultAppInfo(BROWSERTYPE,ui->browserComBoBox);
 
-        } else if(type == IMAGETYPE) {
-            ui->imageComBoBox->setCurrentIndex(index);
-            imageComBoBox_changed_cb(index);
-            connect(ui->imageComBoBox, static_cast<void (QComboBox::*)(int )> (&QComboBox::currentIndexChanged), this, &DefaultApp::imageComBoBox_changed_cb);
+    // IMAGE
+    initDefaultAppInfo(IMAGETYPE,ui->imageComBoBox);
 
-        } else if(type == AUDIOTYPE) {
-            ui->audioComBoBox->setCurrentIndex(index);
-            audioComBoBox_changed_cb(index);
-            connect(ui->audioComBoBox, static_cast<void (QComboBox::*)(int )> (&QComboBox::currentIndexChanged), this, &DefaultApp::audioComBoBox_changed_cb);
+    // MAIL
+    initDefaultAppInfo(MAILTYPE,ui->mailComBoBox);
 
-        } else if(type == VIDEOTYPE) {
-            ui->videoComBoBox->setCurrentIndex(index);
-            videoComBoBox_changed_cb(index);
-            connect(ui->videoComBoBox, static_cast<void (QComboBox::*)(int )> (&QComboBox::currentIndexChanged), this, &DefaultApp::videoComBoBox_changed_cb);
+    // AUDIO
+    initDefaultAppInfo(AUDIOTYPE,ui->audioComBoBox);
 
-        } else if(type == TEXTTYPE) { 
-            ui->textComBoBox->setCurrentIndex(index);
-            textComBoBox_changed_cb(index);
-            connect(ui->textComBoBox, static_cast<void (QComboBox::*)(int )> (&QComboBox::currentIndexChanged), this, &DefaultApp::textComBoBox_changed_cb);
+    // VIDEO
+    initDefaultAppInfo(VIDEOTYPE,ui->videoComBoBox);
 
-        }
-    });
+    // TEXT
+    initDefaultAppInfo(TEXTTYPE,ui->textComBoBox);
 
-    QtConcurrent::run([this] {
-        // BROWSER
-        int browserindex = -1;
-        QString currentbrowser(getDefaultAppId(BROWSERTYPE)); //获取当前
-        AppList * list = getAppIdList(BROWSERTYPE); //获取可选列表
-        if (list) {
-            for (int i = 0; list[i].appid != NULL; i++) {
-                QString single(list[i].appid);
-                QByteArray ba = QString(DESKTOPPATH + single).toUtf8();
-                GDesktopAppInfo * browserinfo = g_desktop_app_info_new_from_filename(ba.constData());
-                QString appname = g_app_info_get_name(G_APP_INFO(browserinfo));
-                const char * iconname = g_icon_to_string(g_app_info_get_icon(G_APP_INFO(browserinfo)));
-                QIcon appicon;
-                appicon = QIcon::fromTheme(QString(iconname));
-
-                ui->browserComBoBox->addItem(appicon, appname, single);
-                if (currentbrowser == single) {
-                    browserindex = i;
-                    emit appInitDone(browserindex, BROWSERTYPE);
-                }
-                if(single.contains("firefox")) {
-                    mDefaultBrowser = appname;
-                }
-
-                free(list[i].appid);
-            }
-            free(list);
-        }
-
-        // MAIL
-        int mailindex = -1;
-        QString currentmail(getDefaultAppId(MAILTYPE));
-        AppList * maillist = getAppIdList(MAILTYPE);
-        if (maillist) {
-            for (int i = 0; maillist[i].appid != NULL; i++) {
-                QString single(maillist[i].appid);
-                QByteArray ba = QString(DESKTOPPATH + single).toUtf8();
-                GDesktopAppInfo * mailinfo = g_desktop_app_info_new_from_filename(ba.constData());
-                QString appname = g_app_info_get_name(G_APP_INFO(mailinfo));
-                const char * iconname = g_icon_to_string(g_app_info_get_icon(G_APP_INFO(mailinfo)));
-                QIcon appicon;
-                appicon = QIcon::fromTheme(QString(iconname));
-
-                ui->mailComBoBox->addItem(appicon, appname, single);
-                if (currentmail == single) {
-                    mailindex = i;
-                    emit appInitDone(mailindex, MAILTYPE);
-                }
-                if ("claws-mail.desktop" == single) {
-                    mDefaultMail = appname;
-                }
-
-                free(maillist[i].appid);
-            }
-            free(maillist);
-        }
-
-        // IMAGE
-        int imageindex = -1;
-        QStringList browserList;
-        QString currentimage(getDefaultAppId(IMAGETYPE));
-        AppList * imagelist = getAppIdList(IMAGETYPE);
-
-        for(int i = 0; i < ui->browserComBoBox->count(); i++){
-            browserList << ui->browserComBoBox->itemText(i);
-        }
-        if (imagelist) {
-            for (int i = 0; imagelist[i].appid != NULL; i++) {
-                QString single(imagelist[i].appid);
-                QByteArray ba = QString(DESKTOPPATH + single).toUtf8();
-                GDesktopAppInfo * imageinfo = g_desktop_app_info_new_from_filename(ba.constData());
-                QString appname = g_app_info_get_name(G_APP_INFO(imageinfo));
-                const char * iconname = g_icon_to_string(g_app_info_get_icon(G_APP_INFO(imageinfo)));
-                QIcon appicon;
-                appicon = QIcon::fromTheme(QString(iconname));
-
-                if(!browserList.contains(appname)){
-                    ui->imageComBoBox->addItem(appicon, appname, single);
-                    free(imagelist[i].appid);
-                }
-
-                if ("eom.desktop" == single) {
-                    mDefaultPic = appname;
-                }
-
-            }
-            free(imagelist);
-        }
-        for(int i = 0; i < ui->imageComBoBox->count(); i++){
-            if(currentimage == ui->imageComBoBox->itemData(i)){
-                imageindex = i;
-                emit appInitDone(imageindex, IMAGETYPE);
-            }
-        }
-
-        // AUDIO
-        int audioindex = -1;
-        QString currentaudio(getDefaultAppId(AUDIOTYPE));
-        AppList * audiolist = getAppIdList(AUDIOTYPE);
-        if (audiolist) {
-            for (int i = 0; audiolist[i].appid != NULL; i++) {
-                QString single(audiolist[i].appid);
-                QByteArray ba = QString(DESKTOPPATH + single).toUtf8();
-                GDesktopAppInfo * audioinfo = g_desktop_app_info_new_from_filename(ba.constData());
-                QString appname = g_app_info_get_name(G_APP_INFO(audioinfo));
-                const char * iconname = g_icon_to_string(g_app_info_get_icon(G_APP_INFO(audioinfo)));
-                QIcon appicon;
-                appicon = QIcon::fromTheme(QString(iconname));
-
-                ui->audioComBoBox->addItem(appicon, appname, single);
-                if (currentaudio == single) {
-                    audioindex = i;
-                    emit appInitDone(audioindex, AUDIOTYPE);
-                }
-                if ("kylin-music.desktop" == single) {
-                    mDefaultAdudio = appname;
-                }
-
-                free(audiolist[i].appid);
-            }
-            free(audiolist);
-        }
-
-        // VIDEO
-        int videoindex =-1;
-        QString currentvideo(getDefaultAppId(VIDEOTYPE));
-        AppList * videolist = getAppIdList(VIDEOTYPE);
-        if (videolist) {
-            for (int i = 0; videolist[i].appid != NULL; i++) {
-                QString single(videolist[i].appid);
-                QByteArray ba = QString(DESKTOPPATH + single).toUtf8();
-                GDesktopAppInfo * videoinfo = g_desktop_app_info_new_from_filename(ba.constData());
-                QString appname = g_app_info_get_name(G_APP_INFO(videoinfo));
-                const char * iconname = g_icon_to_string(g_app_info_get_icon(G_APP_INFO(videoinfo)));
-                QIcon appicon;
-                appicon = QIcon::fromTheme(QString(iconname));
-
-                ui->videoComBoBox->addItem(appicon, appname, single);
-                if (currentvideo == single) {
-                    videoindex = i;
-                    emit appInitDone(videoindex, VIDEOTYPE);
-                }
-                if ("kylin-video.desktop" == single) {
-                    mDefaultVideo = appname;
-                }
-
-                free(videolist[i].appid);
-            }
-            free(videolist);
-        }
-
-        // TEXT
-        int textindex = -1;
-        QString currenttext(getDefaultAppId(TEXTTYPE));
-        AppList * textlist = getAppIdList(TEXTTYPE);
-        if (textlist){
-            for (int i = 0; textlist[i].appid != NULL; i++) {
-                QString single(textlist[i].appid);
-                QByteArray ba = QString(DESKTOPPATH + single).toUtf8();
-                GDesktopAppInfo * textinfo = g_desktop_app_info_new_from_filename(ba.constData());
-                QString appname = g_app_info_get_name(G_APP_INFO(textinfo));
-                const char * iconname = g_icon_to_string(g_app_info_get_icon(G_APP_INFO(textinfo)));
-                QIcon appicon;
-                appicon = QIcon::fromTheme(QString(iconname));
-
-                ui->textComBoBox->addItem(appicon, appname, single);
-                if (currenttext == single) {
-                    textindex = i;
-                    emit appInitDone(textindex, TEXTTYPE);
-                }
-                if ("pluma.desktop" == single) {
-                    mDefaultText = appname;
-                }
-
-                free(textlist[i].appid);
-            }
-            free(textlist);
-        }
-        isCloudEmitted = false;
-    });
 }
 
 void DefaultApp::initSearchText() {
@@ -309,105 +135,145 @@ void DefaultApp::initSearchText() {
     ui->textLabel->setText(tr("Text Editor"));
 }
 
-void DefaultApp::browserComBoBox_changed_cb(int index) {
-    QString appid = ui->browserComBoBox->itemData(index).toString();
-    QByteArray ba = appid.toUtf8(); // QString to char *
+void DefaultApp::initDefaultAppInfo(const char *type, QComboBox *combox)
+{
+    QString currentapp(getDefaultAppId(type));
+    QByteArray ba = QString(DESKTOPPATH + currentapp).toUtf8();
+    GDesktopAppInfo * textinfo = g_desktop_app_info_new_from_filename(ba.constData());
+    QString appname = g_app_info_get_name(G_APP_INFO(textinfo));
+    const char * iconname = g_icon_to_string(g_app_info_get_icon(G_APP_INFO(textinfo)));
+    QIcon appicon;
+    appicon = QIcon::fromTheme(QString(QLatin1String(iconname)),
+                               QIcon(QString("/usr/share/pixmaps/"+QString(QLatin1String(iconname))
+                                             +".png")));
+    if (!appname.isNull()) {
+        combox->addItem(appicon, appname, currentapp);
 
-    bool bRunSync = false;
-
-    isCloudEmitted == false ? setWebBrowsersDefaultProgram(ba.data()):bRunSync = true;
-
-    if(bRunSync == true) {
-        QtConcurrent::run([=] {
-            QString appid = ui->browserComBoBox->itemData(index).toString();
-            QByteArray ba = appid.toUtf8(); // QString to char *
-            setWebBrowsersDefaultProgram(ba.data());
-        });
+        // 将当前默认应用信息写入~/.config/mimeapps.list
+        int i = combox->currentIndex();
+    //    combox->setCurrentText(appname);
+        if (!strcmp(type , BROWSERTYPE)) {
+            browserComBoBox_changed_cb(i);
+        } else if (!strcmp(type , IMAGETYPE)) {
+            imageComBoBox_changed_cb(i);
+        } else if (!strcmp(type , MAILTYPE)) {
+            mailComBoBox_changed_cb(i);
+        } else if (!strcmp(type , AUDIOTYPE)) {
+            audioComBoBox_changed_cb(i);
+        } else if (!strcmp(type , VIDEOTYPE)) {
+            videoComBoBox_changed_cb(i);
+        } else if (!strcmp(type , TEXTTYPE)) {
+            textComBoBox_changed_cb(i);
+        }
+    } else {
+        combox->addItem(mDefaultString);
+        combox->setCurrentText(mDefaultString);
     }
+
+    // 将可用程序加入列表
+    QtConcurrent::run([=]() {
+        QTime timedebuge;//声明一个时钟对象
+        timedebuge.start();//开始计时
+        QString current(getDefaultAppId(type));
+        QVector<AppList> list = getAppIdList(type);
+        if (!list.isEmpty()) {
+            for (int i = 0; i < list.size(); i++) {
+                QString single(list[i].strAppid);
+                QByteArray ba = QString(DESKTOPPATH + single).toUtf8();
+                GDesktopAppInfo * info = g_desktop_app_info_new_from_filename(ba.constData());
+                QString appname = g_app_info_get_name(G_APP_INFO(info));
+                const char * iconname = g_icon_to_string(g_app_info_get_icon(G_APP_INFO(info)));
+                QIcon appicon;
+                appicon = QIcon::fromTheme(QString(QLatin1String(iconname)),
+                                           QIcon(QString("/usr/share/pixmaps/"+QString(QLatin1String(iconname))
+                                                         +".png")));
+                if (current == single) {
+                    continue;
+                }
+                combox->addItem(appicon, appname, single);
+            }
+        }
+        qDebug()<<type<<"  线程耗时: "<<timedebuge.elapsed()<<"ms";
+    });
+
+}
+
+void DefaultApp::browserComBoBox_changed_cb(int index) {
+
+    QtConcurrent::run([=] {
+        QTime timedebuge;//声明一个时钟对象
+        timedebuge.start();//开始计时
+        QString appid = ui->browserComBoBox->itemData(index).toString();
+        QByteArray ba = appid.toUtf8(); // QString to char *
+        qDebug()<<"browserComBoBox_changed_cb："<<timedebuge.elapsed()<<"ms" << appid;
+        setWebBrowsersDefaultProgram(ba.data());
+
+    });
+
 }
 
 void DefaultApp::mailComBoBox_changed_cb(int index) {
-    QString appid = ui->mailComBoBox->itemData(index).toString();
-    QByteArray ba = appid.toUtf8(); // QString to char *
-    bool bRunSync = false;
 
-    isCloudEmitted == false ? setMailReadersDefaultProgram(ba.data()):bRunSync = true;
+    QtConcurrent::run([=] {
+        QTime timedebuge;//声明一个时钟对象
+        timedebuge.start();//开始计时
+        QString appid = ui->mailComBoBox->itemData(index).toString();
+        QByteArray ba = appid.toUtf8(); // QString to char *
+        setMailReadersDefaultProgram(ba.data());
+        qDebug()<<"mailComBoBox_changed_cb线程耗时："<<timedebuge.elapsed()<<"ms";//输出计时
+    });
 
-    if(bRunSync == true) {
-        QtConcurrent::run([=] {
-            QString appid = ui->mailComBoBox->itemData(index).toString();
-            QByteArray ba = appid.toUtf8(); // QString to char *
-            setMailReadersDefaultProgram(ba.data());
-        });
-    }
 }
 
 void DefaultApp::imageComBoBox_changed_cb(int index) {
-    QString appid = ui->imageComBoBox->itemData(index).toString();
-    QByteArray ba = appid.toUtf8(); // QString to char *
 
-    bool bRunSync = false;
+    QtConcurrent::run([=] {
+        QTime timedebuge;//声明一个时钟对象
+        timedebuge.start();//开始计时
+        QString appid = ui->imageComBoBox->itemData(index).toString();
+        QByteArray ba = appid.toUtf8(); // QString to char *
+        setImageViewersDefaultProgram(ba.data());
+        qDebug()<<"imageComBoBox_changed_cb线程耗时："<<timedebuge.elapsed()<<"ms";//输出计时
+    });
 
-    isCloudEmitted == false ? setImageViewersDefaultProgram(ba.data()):bRunSync = true;
-
-    if(bRunSync == true) {
-        QtConcurrent::run([=] {
-            QString appid = ui->imageComBoBox->itemData(index).toString();
-            QByteArray ba = appid.toUtf8(); // QString to char *
-            setImageViewersDefaultProgram(ba.data());
-        });
-    }
 }
 
 void DefaultApp::audioComBoBox_changed_cb(int  index) {
-    QString appid = ui->audioComBoBox->itemData(index).toString();
-    QByteArray ba = appid.toUtf8(); // QString to char *
 
-    bool bRunSync = false;
+    QtConcurrent::run([=] {
+        QTime timedebuge;//声明一个时钟对象
+        timedebuge.start();//开始计时
+        QString appid = ui->audioComBoBox->itemData(index).toString();
+        QByteArray ba = appid.toUtf8(); // QString to char *
+        setAudioPlayersDefaultProgram(ba.data());
+        qDebug()<<"audioComBoBox_changed_cb线程耗时："<<timedebuge.elapsed()<<"ms";//输出计时
+    });
 
-    isCloudEmitted == false ? setAudioPlayersDefaultProgram(ba.data()):bRunSync = true;
-
-    if(bRunSync == true) {
-        QtConcurrent::run([=] {
-            QString appid = ui->audioComBoBox->itemData(index).toString();
-            QByteArray ba = appid.toUtf8(); // QString to char *
-            setAudioPlayersDefaultProgram(ba.data());
-        });
-    }
 }
 
 void DefaultApp::videoComBoBox_changed_cb(int index) {
-    QString appid = ui->videoComBoBox->itemData(index).toString();
-    QByteArray ba = appid.toUtf8(); // QString to char *
 
-    bool bRunSync = false;
+    QtConcurrent::run([=] {
+        QTime timedebuge;//声明一个时钟对象
+        timedebuge.start();//开始计时
+        QString appid = ui->videoComBoBox->itemData(index).toString();
+        QByteArray ba = appid.toUtf8(); // QString to char *
+        setVideoPlayersDefaultProgram(ba.data());
+    });
 
-    isCloudEmitted == false ? setVideoPlayersDefaultProgram(ba.data()):bRunSync = true;
-
-    if(bRunSync == true) {
-        QtConcurrent::run([=] {
-            QString appid = ui->videoComBoBox->itemData(index).toString();
-            QByteArray ba = appid.toUtf8(); // QString to char *
-            setVideoPlayersDefaultProgram(ba.data());
-        });
-    }
 }
 
 void DefaultApp::textComBoBox_changed_cb(int index) {
-    QString appid = ui->textComBoBox->itemData(index).toString();
-    QByteArray ba = appid.toUtf8(); // QString to char *
 
-    bool bRunSync = false;
+    QtConcurrent::run([=] {
+        QTime timedebuge;//声明一个时钟对象
+        timedebuge.start();//开始计时
+        QString appid = ui->textComBoBox->itemData(index).toString();
+        QByteArray ba = appid.toUtf8(); // QString to char *
+        setTextEditorsDefautlProgram(ba.data());
 
-    isCloudEmitted == false ? setTextEditorsDefautlProgram(ba.data()):bRunSync = true;
+    });
 
-    if(bRunSync == true) {
-        QtConcurrent::run([=] {
-            QString appid = ui->textComBoBox->itemData(index).toString();
-            QByteArray ba = appid.toUtf8(); // QString to char *
-            setTextEditorsDefautlProgram(ba.data());
-        });
-    }
 }
 
 void DefaultApp::resetDefaultApp() {
@@ -425,80 +291,62 @@ void DefaultApp::resetDefaultApp() {
     }
 }
 
-char * DefaultApp::getDefaultAppId(const char * contentType) {
+QString DefaultApp::getDefaultAppId(const char * contentType) {
     GAppInfo * app = g_app_info_get_default_for_type(contentType, false);
     if(app != NULL){
         const char * id = g_app_info_get_id(app);
-        if(id != NULL){
-            gint len = strlen(id);
-            char * appid = (char *)malloc(sizeof(char)*(len+1));
-            strcpy(appid,id);
-            return appid;
-        } else {
-            return NULL;
-        }
+        QString strId(id);
+        return strId;
     } else {
-        return NULL;
+        return QString("");
     }
 }
 
-AppList * DefaultApp::getAppIdList(const char *contentType) {
-    Appinfo *appinfo = _getAppList(contentType);
-    if (appinfo != NULL) {
-        int i = 0;
-        while(appinfo[i].item != NULL)
-            i++;
-        AppList *list = (AppList *)malloc(sizeof(AppList)*(i+1));
-        int count = i;
-        int index = 0;
-        for(gint j = 0;appinfo[j].item != NULL;j++) {
+QVector<AppList> DefaultApp::getAppIdList(const char *contentType) {
+    QVector<AppList> appList;
+    appList.clear();
+    QVector<Appinfo> appinfo = _getAppList(contentType);
+    if (!appinfo.isEmpty()) {
+        for(int j = 0; j < appinfo.size(); j++) {
             const char *id = g_app_info_get_id(appinfo[j].item);
             if (id != NULL) {
-                int len = strlen(id);
-                list[index].appid = (char *)malloc(sizeof(char)*(len+1));
-                strcpy(list[index].appid,id);
-                index++;
-            } else {
-                free(list+count);
-                count--;
+                AppList al;
+                al.strAppid = QString(id);
+                appList.append(al);
             }
         }
-        list[count].appid=NULL;
-        free(appinfo);
-        return list;
-    } else {
-        return NULL;
     }
+    return appList;
 }
 
-Appinfo * DefaultApp::_getAppList(const char *contentType) {
+QVector<Appinfo> DefaultApp::_getAppList(const char *contentType) {
     GList *applist;
     applist = g_app_info_get_all_for_type(contentType);
     GAppInfo * item;
+    QVector<Appinfo> appinfo;
+    appinfo.clear();
 
     if (applist != NULL) {
         int len = g_list_length(applist);
-        Appinfo * appinfo=(Appinfo *)malloc(sizeof(Appinfo)*(len+1));
 
         //获取应用列表
         for (int index=0; index < len; index++) {
             item = (GAppInfo*) g_list_nth_data(applist, index);
-            appinfo[index].item=item;
+            Appinfo ai;
+            ai.item = item;
+            appinfo.append(ai);
         }
-        appinfo[len].item=NULL;
-        return appinfo;
-
-    } else {
-        return NULL;
     }
+    return appinfo;
 }
 
 bool DefaultApp::setWebBrowsersDefaultProgram(char * appid) {
+    qDebug() << __func__ << __LINE__;
     const char * content_type = "x-scheme-handler/http";
-    Appinfo * appinfo = _getAppList(content_type);
+    QVector<Appinfo> appinfo = _getAppList(content_type);
     bool judge = false;
-    if (appinfo != NULL) {
-        for(int i = 0; appinfo[i].item != NULL; i++) {
+    if (!appinfo.isEmpty()) {
+        for(int i = 0; i < appinfo.size(); i++) {
             const char *id = g_app_info_get_id(appinfo[i].item);
             int result = strcmp(id,appid);
             if (0 == result) {
@@ -512,18 +360,18 @@ bool DefaultApp::setWebBrowsersDefaultProgram(char * appid) {
                 break;
             }
         }
-        free(appinfo);
     }
+    qDebug() << __func__ << __LINE__;
     return judge;
 }
 
 bool DefaultApp::setMailReadersDefaultProgram(char *appid) {
     const char *content_type="x-scheme-handler/mailto";
-    Appinfo *appinfo=_getAppList(content_type);
+    QVector<Appinfo> appinfo = _getAppList(content_type);
 
     bool judge = false;
-    if (appinfo != NULL) {
-        for (int i = 0; appinfo[i].item != NULL; i++) {
+    if (!appinfo.isEmpty()) {
+        for (int i = 0; i < appinfo.size(); i++) {
             const char * id = g_app_info_get_id(appinfo[i].item);
             int result=strcmp(id,appid);
             if (0 == result) {
@@ -536,18 +384,17 @@ bool DefaultApp::setMailReadersDefaultProgram(char *appid) {
                 break;
             }
         }
-        free(appinfo);
     }
     return judge;
 }
 
 bool DefaultApp::setImageViewersDefaultProgram(char *appid) {
     const char *content_type="image/png";
-    Appinfo *appinfo = _getAppList(content_type);
+    QVector<Appinfo> appinfo = _getAppList(content_type);
 
     bool judge = false;
-    if (appinfo != NULL) {
-        for (int i=0;appinfo[i].item!=NULL;i++){
+    if (!appinfo.isEmpty()) {
+        for (int i=0; i < appinfo.size();i++){
             const char *id = g_app_info_get_id(appinfo[i].item);
             int result = strcmp(id, appid);
             if (0 == result) {
@@ -562,7 +409,6 @@ bool DefaultApp::setImageViewersDefaultProgram(char *appid) {
                 break;
             }
         }
-        free(appinfo);
     }
 
     return judge;
@@ -570,11 +416,11 @@ bool DefaultApp::setImageViewersDefaultProgram(char *appid) {
 
 bool DefaultApp::setVideoPlayersDefaultProgram(char *appid) {
     const char *content_type = "video/x-ogm+ogg";
-    Appinfo * appinfo = _getAppList(content_type);
+    QVector<Appinfo> appinfo = _getAppList(content_type);
 
     bool judge = false;
-    if (appinfo != NULL) {
-        for(int i = 0; appinfo[i].item != NULL; i++) {
+    if (!appinfo.isEmpty()) {
+        for(int i = 0; i < appinfo.size(); i++) {
             const char *id = g_app_info_get_id(appinfo[i].item);
             int result = strcmp(id,appid);
             if (0 == result) {
@@ -632,18 +478,17 @@ bool DefaultApp::setVideoPlayersDefaultProgram(char *appid) {
                 break;
             }
         }
-        free(appinfo);
     }
     return judge;
 }
 
 bool DefaultApp::setAudioPlayersDefaultProgram(char *appid) {
     const char *content_type = "audio/x-vorbis+ogg";
-    Appinfo * appinfo = _getAppList(content_type);
+    QVector<Appinfo> appinfo = _getAppList(content_type);
 
     bool judge = false;
-    if (appinfo != NULL) {
-        for(int i = 0; appinfo[i].item != NULL ;i++) {
+    if (!appinfo.isEmpty()) {
+        for(int i = 0; i < appinfo.size() ;i++) {
             const char *id = g_app_info_get_id(appinfo[i].item);
             int result = strcmp(id,appid);
             if (0 == result) {
@@ -668,25 +513,25 @@ bool DefaultApp::setAudioPlayersDefaultProgram(char *appid) {
                 gboolean ret18 = g_app_info_set_as_default_for_type(appitem, "audio/mp3", NULL);
                 gboolean ret19 = g_app_info_set_as_default_for_type(appitem, "audio/flac", NULL);
                 gboolean ret20 = g_app_info_set_as_default_for_type(appitem, "audio/wma", NULL);
+                gboolean ret21 = g_app_info_set_as_default_for_type(appitem, "application/x-smaf", NULL);
                 if(ret1 && ret2 && ret3 && ret4 && ret5 && ret6 && ret7 && ret8 && ret9 && ret10 &&
-                   ret11 && ret12 && ret13 && ret14 && ret15 && ret16 && ret17 && ret18 && ret19 && ret20) {
+                        ret11 && ret12 && ret13 && ret14 && ret15 && ret16 && ret17 && ret18 && ret19 && ret20 && ret21) {
                     judge=true;
                 }
                 break;
             }
         }
-        free(appinfo);
     }
     return judge;
 }
 
 bool DefaultApp::setTextEditorsDefautlProgram(char *appid) {
     const char * content_type = "text/plain";
-    Appinfo * appinfo = _getAppList(content_type);
+    QVector<Appinfo> appinfo = _getAppList(content_type);
 
     bool judge = false;
-    if (appinfo != NULL) {
-        for (int i = 0; appinfo[i].item != NULL; i++) {
+    if (!appinfo.isEmpty()) {
+        for (int i = 0;i < appinfo.size(); i++) {
             const char * id = g_app_info_get_id(appinfo[i].item);
             int result = strcmp(id,appid);
             if (0 == result) {
@@ -697,31 +542,37 @@ bool DefaultApp::setTextEditorsDefautlProgram(char *appid) {
                 break;
             }
         }
-        free(appinfo);
     }
 
     return judge;
 }
 
 void DefaultApp::connectToServer(){
-    m_cloudInterface = new QDBusInterface("org.kylinssoclient.dbus",
-                                          "/org/kylinssoclient/path",
-                                          "org.freedesktop.kylinssoclient.interface",
-                                          QDBusConnection::sessionBus());
-    if (!m_cloudInterface->isValid())
-    {
-        qDebug() << "fail to connect to service";
-        qDebug() << qPrintable(QDBusConnection::systemBus().lastError().message());
-        return;
-    }
-    QDBusConnection::sessionBus().connect(QString(), QString("/org/kylinssoclient/path"), QString("org.freedesktop.kylinssoclient.interface"), "keyChanged", this, SLOT(keyChangedSlot(QString)));
-    // 将以后所有DBus调用的超时设置为 milliseconds
-    m_cloudInterface->setTimeout(2147483647); // -1 为默认的25s超时
+    QtConcurrent::run([=]() {
+        QTime timedebuge;//声明一个时钟对象
+        timedebuge.start();//开始计时
+        m_cloudInterface = new QDBusInterface("org.kylinssoclient.dbus",
+                                              "/org/kylinssoclient/path",
+                                              "org.freedesktop.kylinssoclient.interface",
+                                              QDBusConnection::sessionBus());
+        if (!m_cloudInterface->isValid())
+        {
+            qDebug() << "fail to connect to service";
+            qDebug() << qPrintable(QDBusConnection::systemBus().lastError().message());
+            return;
+        }
+        QDBusConnection::sessionBus().connect(QString(), QString("/org/kylinssoclient/path"), QString("org.freedesktop.kylinssoclient.interface"), "keyChanged", this, SLOT(keyChangedSlot(QString)));
+        // 将以后所有DBus调用的超时设置为 milliseconds
+        m_cloudInterface->setTimeout(2147483647); // -1 为默认的25s超时
+        qDebug()<<"NetWorkAcount"<<"  线程耗时: "<<timedebuge.elapsed()<<"ms";
+
+
+    });
+
 }
 
 void DefaultApp::keyChangedSlot(const QString &key) {
     if(key == "default-open") {
-        isCloudEmitted = true;
         ui->browserComBoBox->clear();
         ui->audioComBoBox->clear();
         ui->imageComBoBox->clear();
