@@ -1,3 +1,21 @@
+/*
+ * Copyright 2021 KylinSoft Co., Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #ifndef TIMEZONEMAP_H
 #define TIMEZONEMAP_H
 
@@ -52,6 +70,8 @@ private:
     PopList* m_popLists;
     QPixmap loadPixmap(const QString &path);
 
+    QLabel* backgroundLabel;
+
 private slots:
     void popListActiveSlot(int index);
 };
