@@ -24,7 +24,9 @@
 #include "utils/utils.h"
 #include "../commonComponent/ImageUtil/imageutil.h"
 #include "ukccabout.h"
+#include "devicesmonitor.h"
 
+#include <libmatemixer/matemixer.h>
 #include <QLabel>
 #include <QLocale>
 #include <QPushButton>
@@ -38,6 +40,11 @@
 #include <QMessageBox>
 #include <QGSettings>
 #include <QMenu>
+#include <QShortcut>
+#include <QMouseEvent>
+#include <KWindowSystem>
+
+#define STYLE_FONT_SCHEMA  "org.ukui.style"
 
 #ifdef WITHKYSEC
 #include <kysec/libkysec.h>
@@ -53,11 +60,8 @@ const QByteArray kVinoSchemas    = "org.gnome.Vino";
 #undef signals
 #endif
 
-extern "C" {
 #include <glib.h>
 #include <gio/gio.h>
-#include <libmatemixer/matemixer.h>
-}
 
 const int dbWitdth = 50;
 extern void qt_blurImage(QImage &blurImage, qreal radius, bool quality, int transposed);
@@ -68,20 +72,21 @@ MainWindow::MainWindow(QWidget *parent) :
     m_searchWidget(nullptr)
 {
     mate_mixer_init();
-    // 设置初始大小
-    this->setMinimumSize(895, 600);
-    logoLabel  = new QLabel(tr("UKCC"), this);
+    qApp->installEventFilter(this);
     initUI();
 }
 
 MainWindow::~MainWindow()
 {
     delete ui;
+    ui = nullptr;
 }
 
 void MainWindow::bootOptionsFilter(QString opt) {
     if (opt == "--display" || opt == "-m") {
         bootOptionsSwitch(SYSTEM, DISPLAY);
+    }if (opt == "--touchscreen") {
+        bootOptionsSwitch(SYSTEM, TOUCHSCREEN);
     } else if (opt == "--defaultapp") {
         bootOptionsSwitch(SYSTEM, DEFAULTAPP);
     } else if (opt == "--power" || opt == "-p") {
@@ -90,6 +95,8 @@ void MainWindow::bootOptionsFilter(QString opt) {
         bootOptionsSwitch(SYSTEM, AUTOBOOT);
     } else if (opt == "--printer") {
         bootOptionsSwitch(DEVICES, PRINTER);
+    } else if (opt == "--projection") {
+        bootOptionsSwitch(DEVICES, PROJECTION);
     } else if (opt == "--mouse") {
         bootOptionsSwitch(DEVICES, MOUSE);
     } else if (opt == "--touchpad") {
@@ -128,14 +135,16 @@ void MainWindow::bootOptionsFilter(QString opt) {
         bootOptionsSwitch(DATETIME, DAT);
     }  else if (opt == "--area") {
         bootOptionsSwitch(DATETIME, AREA);
-    } else if (opt == "--update") {
-        bootOptionsSwitch(UPDATE, UPDATES);
+    } else if (opt == "--upgrade") {
+        bootOptionsSwitch(UPDATE, UPGRADE);
     } else if (opt == "--backup") {
         bootOptionsSwitch(UPDATE, BACKUP);
     } else if (opt == "--notice" || opt == "-n") {
         bootOptionsSwitch(NOTICEANDTASKS, NOTICE);
     } else if (opt == "--about" || opt == "-a") {
         bootOptionsSwitch(NOTICEANDTASKS, ABOUT);
+    } else if (opt == "--search") {
+        bootOptionsSwitch(NOTICEANDTASKS, SEARCH);
     }
 }
 
@@ -155,33 +164,27 @@ void MainWindow::bootOptionsSwitch(int moduleNum, int funcNum){
 }
 
 bool MainWindow::eventFilter(QObject *watched, QEvent *event) {
+    /* clear m_searchWidget's focus
+     * MouseButtonPress event happened but not in m_searchWidget
+     */
+    if (event->type() == QEvent::MouseButtonPress) {
+        QMouseEvent *mEvent = static_cast<QMouseEvent*>(event);
+        QWidget *searchParentWid = static_cast<QWidget*>(m_searchWidget->parent());
+        QPoint  searchPoint      = searchParentWid->mapFromGlobal(mEvent->globalPos());
+        //qDebug()<<m_searchWidget->geometry()<<  mWindowGlobalPoint << mouseGlobalPoint << tPoint;
+        if (!m_searchWidget->geometry().contains(searchPoint)) {
+                if (m_isSearching == true) {
+                    m_searchWidget->setFocus();
+                    m_searchWidget->clearFocus();
+                }
+        }
+    }
     if (this == watched) {
         if (event->type() == QEvent::WindowStateChange) {
-            int count = ui->leftsidebarVerLayout->count();
             if (this->windowState() == Qt::WindowMaximized) {
-                QFont font = this->font();
-                int width = font.pointSize();
                 maxBtn->setIcon(QIcon::fromTheme("window-restore-symbolic"));
-                ui->leftsidebarWidget->setMaximumWidth(width * 10 +25);
-                for (int i = 0; i < count; i++) {
-                    QPushButton * btn = static_cast<QPushButton *>(ui->leftsidebarVerLayout->itemAt(i)->widget());
-                    if (btn) {
-                        QLayout *layout = btn->layout();
-                        QLabel * tipLabel = static_cast<QLabel *>(layout->itemAt(1)->widget());
-                        tipLabel->setVisible(true);
-                    }
-                }
             } else {
                 maxBtn->setIcon(QIcon::fromTheme("window-maximize-symbolic"));
-                ui->leftsidebarWidget->setMaximumWidth(60);
-                for (int i = 0; i < count; i++) {
-                    QPushButton * btn = static_cast<QPushButton *>(ui->leftsidebarVerLayout->itemAt(i)->widget());
-                    if (btn) {
-                        QLayout *layout = btn->layout();
-                        QLabel * tipLabel = static_cast<QLabel *>(layout->itemAt(1)->widget());
-                        tipLabel->setVisible(false);
-                    }
-                }
             }
         } else if (event->type() == QEvent::MouseButtonDblClick) {
             bool res = dblOnEdge(dynamic_cast<QMouseEvent*>(event));
@@ -200,7 +203,7 @@ bool MainWindow::eventFilter(QObject *watched, QEvent *event) {
                 m_animation->stop();
                 m_animation->setStartValue(QRect((m_searchWidget->width()-(m_queryIcon->width()+m_queryText->width()+10))/2,0,
                                                  m_queryIcon->width()+m_queryText->width()+30,(m_searchWidget->height()+32)/2));
-                m_animation->setEndValue(QRect(0, 0, m_queryIcon->width() + 5,(m_searchWidget->height()+32)/2));
+                m_animation->setEndValue(QRect(8, 0, m_queryIcon->width() + 5,(m_searchWidget->height()+32)/2));
                 m_animation->setEasingCurve(QEasingCurve::OutQuad);
                 m_animation->start();
                 m_searchWidget->setTextMargins(30, 1, 0, 1);
@@ -226,23 +229,42 @@ bool MainWindow::eventFilter(QObject *watched, QEvent *event) {
 }
 
 void MainWindow::initUI() {
+    QRect screenSize = Utils::sizeOnCursor();
+    if (screenSize.width() <= 1440) {
+        this->setMinimumSize(978, 630);
+    } else {
+        this->setMinimumSize(1160, 720);
+    }
     ui->setupUi(this);
     ui->centralWidget->setStyleSheet("QWidget#centralWidget{background: palette(base); border-radius: 6px;}");
 
     m_ModuleMap = Utils::getModuleHideStatus();
 
-    this->installEventFilter(this);
-
     const QByteArray id("org.ukui.style");
-    QGSettings * fontSetting = new QGSettings(id, QByteArray(), this);
-    connect(fontSetting, &QGSettings::changed,[=](QString key) {
+    m_fontSetting = new QGSettings(id, QByteArray(), this);
+    connect(m_fontSetting, &QGSettings::changed, this, [=](QString key) {
         if ("systemFont" == key || "systemFontSize" ==key) {
+            changeSearchSlot();
             QFont font = this->font();
             int width = font.pointSize();
             for (auto widget : qApp->allWidgets()) {
-                widget->setFont(font);
+                QString className(widget->metaObject()->className());
+                if (widget->objectName() == "timeClockLable") {
+                    QFont fontTime;
+                    font.setWeight(QFont::Medium);
+                    fontTime.setPixelSize(font.pointSize() * 23 / 11);
+                    widget->setFont(fontTime);
+                } else if(className.contains("TitleLabel")) {
+                    QFont fontTitle;
+                    fontTitle.setPixelSize(font.pointSize() * 18 / 11);
+                    fontTitle.setWeight(QFont::Medium);
+                    widget->setFont(fontTitle); 
+                } else {
+                    font.setWeight(QFont::Normal);
+                    widget->setFont(font);
+                }
             }
-            ui->leftsidebarWidget->setMaximumWidth(width * 10 +20);
+            ui->leftsidebarWidget->setMaximumWidth(width * 10 + 20);
         }
     });
 
@@ -261,7 +283,6 @@ void MainWindow::initUI() {
     //加载插件
     loadPlugins();
 
-    connect(mOptionBtn, SIGNAL(clicked()), this, SLOT(showUkccAboutSlot()));
     connect(minBtn, SIGNAL(clicked()), this, SLOT(showMinimized()));
     connect(maxBtn, &QPushButton::clicked, this, [=] {
         if (isMaximized()) {
@@ -274,23 +295,33 @@ void MainWindow::initUI() {
     });
     connect(closeBtn, &QPushButton::clicked, this, [=] {
         close();
+        exit(0);
     });
 
     connect(ui->stackedWidget, &QStackedWidget::currentChanged, this, [=](int index){
-        //左侧边栏显示/不显示
-        ui->leftsidebarWidget->setVisible(index);
-        //左上角显示字符/返回按钮
-        backBtn->setVisible(index);
-        titleLabel->setHidden(index);
-        mTitleIcon->setHidden(index);
-
+        ui->centralWidget->setVisible(false);    //避免出现明显的卡顿现象，在选择进入屏保界面之后这个问题比较明显，这种做法只是优化
         if (index){ //首页部分组件样式
-            //中部内容区域
+            titleLabel->setHidden(true);
+            mTitleIcon->setHidden(true);
+              ui->leftsidebarWidget->setVisible(true);
+            //左上角显示字符/返回按钮
+            backBtn->setVisible(true);
+
             ui->stackedWidget->setStyleSheet("QStackedWidget#stackedWidget{background: palette(base); border-bottom-right-radius: 6px;}");
         } else { //次页部分组件样式
+            //左侧边栏显示/不显示
+            ui->leftsidebarWidget->setHidden(true);
+            titleLabel->setVisible(true);
+            mTitleIcon->setVisible(true);
+            //左上角显示字符/返回按钮
+            backBtn->setHidden(true);
+            if (modulepageWidget) {
+                modulepageWidget->pluginLeave();
+            }
             //中部内容区域
             ui->stackedWidget->setStyleSheet("QStackedWidget#stackedWidget{background:  palette(base); border-bottom-left-radius: 6px; border-bottom-right-radius: 6px;}");
         }
+        ui->centralWidget->setVisible(true);
     });
 
     //加载左侧边栏一级菜单
@@ -321,16 +352,23 @@ void MainWindow::initUI() {
     if (QApplication::arguments().length() > 1) {
         bootOptionsFilter(QApplication::arguments().at(1));
     }
+
+    //快捷键
+    new QShortcut(QKeySequence(Qt::Key_F1), this, SLOT(onF1ButtonClicked()));
 }
 
 void MainWindow::initTileBar() {
 
-    ui->titleLayout->setContentsMargins(8, 4, 4, 0);
-    ui->titleLayout->setSpacing(0);
+    titleLayout = new QHBoxLayout(ui->titleWidget);
+    ui->titleWidget->setLayout(titleLayout);
+    ui->titleWidget->setObjectName("titleWidget");
+    ui->titleWidget->setStyleSheet("QWidget#titleWidget{background-color:palette(base)}");
+    titleLayout->setContentsMargins(8, 4, 4, 0);
+    titleLayout->setSpacing(0);
     m_searchWidget = new SearchWidget(this);
+    m_searchWidget->setStyleSheet("background-color:palette(windowtext)");
     m_searchWidget->setFocusPolicy(Qt::ClickFocus);
-    m_searchWidget->installEventFilter(this);
-
+    
     m_queryWid = new QWidget;
     m_queryWid->setParent(m_searchWidget);
     m_queryWid->setFocusPolicy(Qt::NoFocus);
@@ -344,6 +382,7 @@ void MainWindow::initTileBar() {
     QIcon searchIcon = QIcon::fromTheme("edit-find-symbolic");
     m_queryIcon = new QLabel(this);
     m_queryIcon->setPixmap(searchIcon.pixmap(searchIcon.actualSize(QSize(16, 16))));
+    m_queryIcon->setProperty("useIconHighlightEffect",0x10);
 
     m_queryText = new QLabel(this);
     m_queryText->setText(tr("Search"));
@@ -355,18 +394,18 @@ void MainWindow::initTileBar() {
     m_searchWidget->setContextMenuPolicy(Qt::NoContextMenu);
     m_animation= new QPropertyAnimation(m_queryWid, "geometry", this);
     m_animation->setDuration(100);
-    ui->titleLayout->addWidget(m_searchWidget,Qt::AlignCenter);
+    titleLayout->addWidget(m_searchWidget,Qt::AlignCenter);
     connect(m_animation,&QPropertyAnimation::finished,this,&MainWindow::animationFinishedSlot);
 
     connect(m_searchWidget, &SearchWidget::notifyModuleSearch, this, &MainWindow::switchPage);
 
     backBtn     = new QPushButton(this);
-    mOptionBtn  = new QPushButton(this);
+    mOptionBtn  = new QToolButton(this);
     minBtn      = new QPushButton(this);
     maxBtn      = new QPushButton(this);
     closeBtn    = new QPushButton(this);
     mTitleIcon  = new QLabel(this);
-    titleLabel  = new QLabel(tr("UKCC"), this);
+    titleLabel  = new QLabel(tr("Settings"), this);
 
     backBtn->setFixedSize(30, 30);
     mOptionBtn->setFixedSize(30, 30);
@@ -375,28 +414,35 @@ void MainWindow::initTileBar() {
     closeBtn->setFixedSize(30, 30);
     mTitleIcon->setFixedSize(24, 24);
 
+    mOptionBtn->setToolTip(tr("Main menu"));
+    minBtn->setToolTip(tr("Minimize"));
+    maxBtn->setToolTip(tr("Maximize/Normal"));
+    closeBtn->setToolTip(tr("Close"));
+
     QIcon titleIcon = QIcon::fromTheme("ukui-control-center");
     mTitleIcon->setPixmap(titleIcon.pixmap(titleIcon.actualSize(QSize(24, 24))));
 
     titleLabel->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
 
-    m_searchWidget->setFixedHeight(32);
+    changeSearchSlot();
     m_searchWidget->setFixedWidth(350);
 
-    ui->titleLayout->addWidget(mTitleIcon);
-    ui->titleLayout->addSpacing(8);
-    ui->titleLayout->addWidget(titleLabel);
-    ui->titleLayout->addWidget(backBtn);
-    ui->titleLayout->addStretch();
-    ui->titleLayout->addWidget(m_searchWidget);
-    ui->titleLayout->addStretch();
-    ui->titleLayout->addWidget(mOptionBtn);
-    ui->titleLayout->addSpacing(4);
-    ui->titleLayout->addWidget(minBtn);
-    ui->titleLayout->addSpacing(4);
-    ui->titleLayout->addWidget(maxBtn);
-    ui->titleLayout->addSpacing(4);
-    ui->titleLayout->addWidget(closeBtn);
+    titleLayout->addWidget(mTitleIcon);
+    titleLayout->addSpacing(8);
+    titleLayout->addWidget(titleLabel);
+    titleLayout->addWidget(backBtn);
+    titleLayout->addStretch();
+    titleLayout->addWidget(m_searchWidget);
+    titleLayout->addStretch();
+    titleLayout->addWidget(mOptionBtn);
+    titleLayout->addSpacing(4);
+    titleLayout->addWidget(minBtn);
+    titleLayout->addSpacing(4);
+    titleLayout->addWidget(maxBtn);
+    titleLayout->addSpacing(4);
+    titleLayout->addWidget(closeBtn);
+
+    initUkccAbout();
 }
 void MainWindow::animationFinishedSlot()
 {
@@ -413,9 +459,27 @@ void MainWindow::animationFinishedSlot()
     }
 }
 
-void MainWindow::showUkccAboutSlot() {
+void MainWindow::onF1ButtonClicked() {
+    qDebug() << "onF1ButtonClicked";
+    QString command = "kylin-user-guide";
+
+    QProcess p(0);
+    QStringList args;
+
+    args.append("-A");
+    args.append("ukui-control-center");
+
+    p.startDetached(command,args);//command是要执行的命令,args是参数
+    p.waitForFinished(-1);
+}
+
+void MainWindow::initUkccAbout() {
+
+    mOptionBtn->setStyleSheet("background-color: palette(base);");
+    mOptionBtn->setPopupMode(QToolButton::InstantPopup);
     QMenu* ukccMain = new QMenu(this);
     ukccMain->setObjectName("mainMenu");
+    mOptionBtn->setMenu(ukccMain);
 
     QAction* ukccHelp = new QAction(tr("Help"),this);
     ukccMain->addAction(ukccHelp);
@@ -423,7 +487,6 @@ void MainWindow::showUkccAboutSlot() {
     ukccMain->addAction(ukccAbout);
     QAction* ukccExit = new QAction(tr("Exit"),this);
     ukccMain->addAction(ukccExit);
-    QPoint pt= QPoint(mOptionBtn->x() + 10, mOptionBtn->y()+mOptionBtn->height());
 
     connect(ukccExit, SIGNAL(triggered()), this, SLOT(close()));
 
@@ -436,10 +499,8 @@ void MainWindow::showUkccAboutSlot() {
         QProcess process(this);
         process.startDetached("kylin-user-guide -A ukui-control-center");
     });
-
-    ukccMain->exec(this->mapToGlobal(pt));
 }
-void MainWindow::setBtnLayout(QPushButton * &pBtn){
+void MainWindow::setBtnLayout(QPushButton * &pBtn) {
     QLabel * imgLabel = new QLabel(pBtn);
     QSizePolicy imgLabelPolicy = imgLabel->sizePolicy();
     imgLabelPolicy.setHorizontalPolicy(QSizePolicy::Fixed);
@@ -479,22 +540,21 @@ void MainWindow::loadPlugins(){
         //三权分立开启
 #ifdef WITHKYSEC
         if (!kysec_is_disabled() && kysec_get_3adm_status() && (getuid() || geteuid())){
-            //时间和日期 | 用户账户 | 电源管理 |网络连接 |网络代理
+            //时间和日期 | 用户帐户 | 电源管理 |网络连接 |网络代理
             if (fileName.contains("datetime") || fileName.contains("userinfo") || fileName.contains("power") || \
-                    fileName.contains("netconnect") || fileName.contains("proxy"))
+                    fileName.contains("netconnect") || fileName.contains("proxy") || fileName.contains("update") || \
+                    fileName.contains("upgrade") || fileName.contains("backup"))
                 continue;
         }
 #endif
-
-        if (!fileName.endsWith(".so")) {
-            continue;
-        } else if (fileName == "libexperienceplan.so") {
-            continue;
-        } else if ("libnetworkaccount.so" == fileName && !isExitsCloudAccount()) {
-            continue;
-        } else if (!QGSettings::isSchemaInstalled(kVinoSchemas) && "libvino.so" == fileName) {
-            continue;
-        } else if ("libbluetooth.so" == fileName && !isExitBluetooth()) {
+        if (!fileName.endsWith(".so")
+                || (fileName == "libexperienceplan.so")
+                || ("libnetworkaccount.so" == fileName && !isExitsCloudAccount())
+                || (!QGSettings::isSchemaInstalled(kVinoSchemas) && "libvino.so" == fileName)
+                || ("libbluetooth.so" == fileName && !isExitBluetooth())
+                || ("libpower.so" == fileName && !isExitsPower())
+                || ("libupdate.so" == fileName && !Utils::isCommunity())
+                || ("libtouchpad.so" == fileName && !isfindSynaptics())) {
             continue;
         }
 
@@ -510,6 +570,11 @@ void MainWindow::loadPlugins(){
              !g_file_test(sessionFile, G_FILE_TEST_EXISTS)) &&
                 (fileName == "libscreensaver.so" || fileName == "libscreenlock.so"))
             continue;
+#ifdef __sw_64__
+        if ("libpower.so" == fileName) {
+            continue;
+        }
+#endif
 
         const char * securityCmd = "/usr/sbin/ksc-defender";
 
@@ -543,15 +608,30 @@ void MainWindow::initLeftsideBar(){
     leftBtnGroup = new QButtonGroup();
     leftMicBtnGroup = new QButtonGroup();
 
+    QHBoxLayout *setLayout = new QHBoxLayout(this);
+    QLabel  *logoSetLabel  = new QLabel(this);
+    QLabel  *textSetLable  = new QLabel(this);
+    QWidget *setWidget     = new QWidget(this);
+
+    ui->leftsidebarVerLayout->setSpacing(5);
+    ui->leftsidebarVerLayout->setContentsMargins(7,0,9,0);
+    ui->leftsidebarVerLayout->addWidget(setWidget);
+    setWidget->setLayout(setLayout);
+    setLayout->addWidget(logoSetLabel);
+    setLayout->addWidget(textSetLable);
+    logoSetLabel->setFixedSize(24,24);
+    logoSetLabel->setPixmap(QPixmap::fromImage(QIcon::fromTheme("ukui-control-center").pixmap(24,24).toImage()));
+    textSetLable->setText(tr("Settings"));
+    textSetLable->setAlignment(Qt::AlignLeft);
+
+    ui->leftsidebarVerLayout->addSpacing(8);
     //构建左侧边栏返回首页按钮
     QPushButton * hBtn = buildLeftsideBtn("homepage",tr("Home"));
     hBtn->setObjectName("homepage");
     connect(hBtn, &QPushButton::clicked, this, [=]{
         ui->stackedWidget->setCurrentIndex(0);
     });
-    hBtn->setStyleSheet("QPushButton#homepage{background: palette(window); border: none;}");
-    //    hBtn->setStyleSheet("QPushButton#homepage{background: palette(base);}");
-    ui->leftsidebarVerLayout->addStretch();
+    hBtn->setStyleSheet("QPushButton#homepage{border-radius: 4px;}");
     ui->leftsidebarVerLayout->addWidget(hBtn);
 
     for(int type = 0; type < TOTALMODULES; type++) {
@@ -575,8 +655,9 @@ void MainWindow::initLeftsideBar(){
             button->setCheckable(true);
             leftBtnGroup->addButton(button, type);
 
-            button->setStyleSheet("QPushButton::checked{background: palette(base); border-top-left-radius: 6px;border-bottom-left-radius: 6px;}"
-                                  "QPushButton::!checked{background: palette(window);border: none;}");
+            button->setStyleSheet("QPushButton:hover{background-color: rgba(55,144,250,0.30);border-radius: 4px;}"
+                                 "QPushButton:checked{background-color: palette(highlight);border-radius: 4px;}"
+                                 "QPushButton:!checked{border: none;}");
 
             connect(button, &QPushButton::clicked, this, [=]{
                 QPushButton * btn = dynamic_cast<QPushButton *>(QObject::sender());
@@ -588,9 +669,11 @@ void MainWindow::initLeftsideBar(){
                 QMap<QString, QObject *> currentFuncMap = modulesList[selectedInt];
 
                 for (FuncInfo tmpStruct : tmpList){
-                    if (currentFuncMap.keys().contains(tmpStruct.namei18nString)){
-                        modulepageWidget->switchPage(currentFuncMap.value(tmpStruct.namei18nString));
-                        break;
+                    if (currentFuncMap.keys().contains(tmpStruct.namei18nString)) {
+                        if (m_ModuleMap.isEmpty() || m_ModuleMap[tmpStruct.nameString.toLower()].toBool()) {
+                            modulepageWidget->switchPage(currentFuncMap.value(tmpStruct.namei18nString));
+                            break;
+                        }
                     }
                 }
             });
@@ -610,17 +693,16 @@ QPushButton * MainWindow::buildLeftsideBtn(QString bname,QString tipName) {
     leftsidebarBtn->setAttribute(Qt::WA_DeleteOnClose);
     leftsidebarBtn->setCheckable(true);
     //    leftsidebarBtn->setFixedSize(QSize(60, 56)); //Widget Width 60
-    leftsidebarBtn->setFixedHeight(56);
+    leftsidebarBtn->setFixedSize(155,40);  //一级菜单按钮显示的宽度
 
     QPushButton * iconBtn = new QPushButton(leftsidebarBtn);
     iconBtn->setCheckable(true);
     iconBtn->setFixedSize(QSize(24, 24));
     iconBtn->setFocusPolicy(Qt::NoFocus);
 
-
-    QString iconHomePageBtnQss = QString("QPushButton{background: palette(window); border: none;}");
-    QString iconBtnQss = QString("QPushButton:checked{background: palette(base); border: none;}"
-                                 "QPushButton:!checked{background: palette(window); border: none;}");
+    QString iconHomePageBtnQss = QString("QPushButton{border:  none;}");
+    QString iconBtnQss = QString("QPushButton:checked{border:  none;}"
+                                 "QPushButton:!checked{border: none;}");
     QString path = QString("://img/primaryleftmenu/%1.svg").arg(iname);
     QPixmap pix = ImageUtil::loadSvg(path, "default");
     //单独设置HomePage按钮样式
@@ -632,15 +714,51 @@ QPushButton * MainWindow::buildLeftsideBtn(QString bname,QString tipName) {
     }
     iconBtn->setIcon(pix);
 
+    QLabel * textLabel = new QLabel(leftsidebarBtn);
+    textLabel->setFixedWidth(leftsidebarBtn->width()-40);
+    QFontMetrics  fontMetrics(textLabel->font());
+    int fontSize = fontMetrics.width(tipName);
+    if (fontSize > textLabel->width()) {
+        textLabel->setText(fontMetrics.elidedText(tipName, Qt::ElideRight, textLabel->width()));
+    } else {
+        textLabel->setText(tipName);
+    }
+    const QByteArray styleID(STYLE_FONT_SCHEMA);
+    QGSettings *stylesettings = new QGSettings(styleID, QByteArray(), this);
+    connect(stylesettings,&QGSettings::changed,[=](QString key)
+    {
+        if("systemFont" == key || "systemFontSize" == key)
+        {
+            QFontMetrics  fontMetrics_1(textLabel->font());
+            int fontSize_1 = fontMetrics_1.width(tipName);
+
+            if (fontSize_1 > textLabel->width()) {
+                qDebug()<<textLabel->width();
+                textLabel->setText(fontMetrics_1.elidedText(tipName, Qt::ElideRight, textLabel->width()));
+            } else {
+                textLabel->setText(tipName);
+            }
+        }
+    });
+
+
+    QSizePolicy textLabelPolicy = textLabel->sizePolicy();
+    textLabelPolicy.setHorizontalPolicy(QSizePolicy::Fixed);
+    textLabelPolicy.setVerticalPolicy(QSizePolicy::Fixed);
+    textLabel->setSizePolicy(textLabelPolicy);
+    textLabel->setScaledContents(true);
+
     leftMicBtnGroup->addButton(iconBtn, itype);
 
     connect(iconBtn, &QPushButton::toggled, this, [=] (bool checked) {
         QString path = QString("://img/primaryleftmenu/%1.svg").arg(iname);
         QPixmap pix;
         if (checked) {
-            pix = ImageUtil::loadSvg(path, "blue");
+            pix = ImageUtil::loadSvg(path, "white");
+            textLabel->setStyleSheet("color:white");
         } else {
             pix = ImageUtil::loadSvg(path, "default");
+            textLabel->setStyleSheet("color:palette(windowText)");
         }
         iconBtn->setIcon(pix);
     });
@@ -652,23 +770,17 @@ QPushButton * MainWindow::buildLeftsideBtn(QString bname,QString tipName) {
         QString path = QString("://img/primaryleftmenu/%1.svg").arg(iname);
         QPixmap pix;
         if (checked) {
-            pix = ImageUtil::loadSvg(path, "blue");
+            pix = ImageUtil::loadSvg(path, "white");
+            textLabel->setStyleSheet("color:white");
         } else {
             pix = ImageUtil::loadSvg(path, "default");
+            textLabel->setStyleSheet("color:palette(windowText)");
         }
         iconBtn->setIcon(pix);
     });
 
-    QLabel * textLabel = new QLabel(leftsidebarBtn);
-    textLabel->setVisible(false);
-    textLabel->setText(tipName);
-    QSizePolicy textLabelPolicy = textLabel->sizePolicy();
-    textLabelPolicy.setHorizontalPolicy(QSizePolicy::Fixed);
-    textLabelPolicy.setVerticalPolicy(QSizePolicy::Fixed);
-    textLabel->setSizePolicy(textLabelPolicy);
-    textLabel->setScaledContents(true);
-
     QHBoxLayout * btnHorLayout = new QHBoxLayout();
+    btnHorLayout->setContentsMargins(8, 0, 0, 0);
     btnHorLayout->addWidget(iconBtn, Qt::AlignCenter);
     btnHorLayout->addWidget(textLabel);
     btnHorLayout->addStretch();
@@ -696,6 +808,19 @@ bool MainWindow::isExitsCloudAccount() {
     return false;
 }
 
+bool MainWindow::isExitsPower()
+{
+    QProcess *process = new QProcess;
+    process->start("dpkg -l ukui-power-manager");
+    process->waitForFinished();
+
+    QByteArray ba = process->readAllStandardOutput();
+    delete process;
+    QString mOutput = QString(ba.data());
+
+    return mOutput.contains("ii", Qt::CaseSensitive) ? true : false;
+}
+
 bool MainWindow::dblOnEdge(QMouseEvent *event) {
     QPoint pos = event->globalPos();
     int globalMouseY = pos.y();
@@ -713,8 +838,8 @@ void MainWindow::initStyleSheet() {
     if (QIcon::hasThemeIcon("ukui-control-center"))
         panelicon = QIcon::fromTheme("ukui-control-center");
 
-    this->setWindowIcon(panelicon);
-    this->setWindowTitle(tr("ukcc"));
+    qApp->setWindowIcon(panelicon);
+    this->setWindowTitle(tr("Settings"));
 
     // 中部内容区域
     ui->stackedWidget->setStyleSheet("QStackedWidget#stackedWidget{background: palette(base); border-bottom-left-radius: 6px; border-bottom-right-radius: 6px;}");
@@ -726,7 +851,7 @@ void MainWindow::initStyleSheet() {
 
     mOptionBtn->setProperty("useIconHighlightEffect", 0x2);
     mOptionBtn->setProperty("isWindowButton", 0x01);
-    mOptionBtn->setFlat(true);
+
 
     minBtn->setProperty("useIconHighlightEffect", 0x2);
     minBtn->setProperty("isWindowButton", 0x01);
@@ -739,7 +864,12 @@ void MainWindow::initStyleSheet() {
     closeBtn->setProperty("isWindowButton", 0x02);
     closeBtn->setProperty("useIconHighlightEffect", 0x08);
     closeBtn->setFlat(true);
-    ui->leftsidebarWidget->setStyleSheet("QWidget#leftsidebarWidget{background-color: palette(window);border: none; border-top-left-radius: 6px; border-bottom-left-radius: 6px;}");
+    ui->leftsidebarWidget->setMinimumWidth(153);
+
+    ui->centralWidget->setAttribute(Qt::WA_TranslucentBackground);
+    ui->leftsidebarWidget->setMinimumWidth(176); //一级菜单宽度
+
+ 
 
     // 设置左上角按钮图标
     backBtn->setIcon(QIcon("://img/titlebar/back.svg"));
@@ -757,7 +887,22 @@ bool MainWindow::isExitBluetooth() {
     process.waitForFinished();
     QByteArray output = process.readAllStandardOutput();
     QString str_output = output;
-    return str_output.contains(QString("bluetooth"), Qt::CaseInsensitive);
+    bool isDevice = str_output.contains(QString("bluetooth"), Qt::CaseInsensitive);
+    bool isAddress = true;
+
+    QByteArray bluetoothId("org.ukui.bluetooth");
+    if (QGSettings::isSchemaInstalled(bluetoothId)) {
+        QGSettings bluetoothGSetting(bluetoothId);
+        isAddress = bluetoothGSetting.get("adapter-address").toString().isEmpty() ? false : true;
+    } else
+        isAddress = false;
+
+    return isDevice && isAddress;
+}
+
+void MainWindow::changeSearchSlot() {
+    int fontSize = m_fontSetting->get("system-font-size").toInt();
+    m_searchWidget->setFixedHeight((fontSize - 11) * 2 + 32);
 }
 
 void MainWindow::setModuleBtnHightLight(int id) {
@@ -780,7 +925,13 @@ void MainWindow::functionBtnClicked(QObject *plugin) {
 
 void MainWindow::sltMessageReceived(const QString &msg) {
 
-    showNormal();
+//    if (!this->isActiveWindow()) {
+//        this->hide();
+//        this->show();
+//        showNormal();
+//    }
+    KWindowSystem::forceActiveWindow(this->winId());
+    this->show();
     bootOptionsFilter(msg);
 
     //Qt::WindowFlags flags = windowFlags();
@@ -790,14 +941,31 @@ void MainWindow::sltMessageReceived(const QString &msg) {
     //setWindowFlags(flags);
 }
 
-void MainWindow::switchPage(QString moduleName) {
+void MainWindow::switchPage(QString moduleName, QString jumpMoudle) {
 
     for (int i = 0; i < modulesList.length(); i++) {
         auto modules = modulesList.at(i);
         //开始跳转
         if (modules.keys().contains(moduleName)) {
-            ui->stackedWidget->setCurrentIndex(1);
-            modulepageWidget->switchPage(modules.value(moduleName));
+            if (m_ModuleMap.isEmpty() || m_ModuleMap[jumpMoudle.toLower()].toBool()) {
+                ui->stackedWidget->setCurrentIndex(1);
+                modulepageWidget->switchPage(modules.value(moduleName));
+                return ;
+            }
         }
     }
+    QMessageBox::information(this, tr("Warning"), tr("This function has been controlled"));
+    return;
+}
+
+void MainWindow::moveEvent(QMoveEvent *event)
+{
+    Q_UNUSED(event);
+    Q_EMIT posChanged();
+}
+
+void MainWindow::resizeEvent(QResizeEvent *event)
+{
+    QMainWindow::resizeEvent(event);
+    Q_EMIT posChanged();
 }
