@@ -30,13 +30,15 @@
 #include <QPainter>
 #include <QPropertyAnimation>
 #include <QVariantMap>
+#include <QGSettings/QGSettings>
+#include <QHBoxLayout>
+#include <QToolButton>
 
 #include "interface.h"
 #include "homepagewidget.h"
 #include "modulepagewidget.h"
 #include "searchwidget.h"
 
-
 class QLabel;
 class QPushButton;
 class QButtonGroup;
@@ -57,10 +59,11 @@ public:
 public:
     QMap<QString, QObject *> exportModule(int);
     void setModuleBtnHightLight(int id);
-
+    static bool isExitBluetooth();
     void bootOptionsFilter(QString opt);
     void bootOptionsSwitch(int moduleNum, int funcNum);
-
+    void moveEvent(QMoveEvent *event);
+    void resizeEvent(QResizeEvent *event);
 protected:
     bool eventFilter(QObject *watched, QEvent *event);
 
@@ -69,7 +72,7 @@ private:
 
 private:
     HomePageWidget * homepageWidget;
-    ModulePageWidget * modulepageWidget;
+    ModulePageWidget * modulepageWidget = nullptr;
 
     QButtonGroup * leftBtnGroup;
     QButtonGroup * leftMicBtnGroup; //
@@ -79,24 +82,26 @@ private:
     QList<QMap<QString, QObject *>> modulesList;
 
     KeyValueConverter * kvConverter;
-    SearchWidget * m_searchWidget;
+    SearchWidget      * m_searchWidget;
 
     QPushButton *backBtn;
-    QPushButton *mOptionBtn;
+    QToolButton *mOptionBtn;
     QPushButton *minBtn;
     QPushButton *maxBtn;
     QPushButton *closeBtn;
     QLabel      *titleLabel;
     QLabel      *mTitleIcon;
     QTimer      *timer;
-    QLabel      *logoLabel;
     QLabel            *m_queryIcon;
     QLabel            *m_queryText  = nullptr;
     QPropertyAnimation *m_animation = nullptr;
     QWidget           *m_queryWid   = nullptr;
-    bool              m_isSearching;
+    bool              m_isSearching = false;
     QString           m_searchKeyWords;
     QVariantMap       m_ModuleMap;
+    QGSettings       *m_fontSetting;
+
+    QHBoxLayout     *titleLayout;
 
 private:
     void initUI();
@@ -106,17 +111,22 @@ private:
     void initLeftsideBar();
     QPushButton * buildLeftsideBtn(QString bname, QString tipName);
     bool isExitsCloudAccount();
-
+    bool isExitsPower();
     bool dblOnEdge(QMouseEvent *event);
     void initStyleSheet();
-    bool isExitBluetooth();
+    void changeSearchSlot();
 
 public slots:
     void functionBtnClicked(QObject * plugin);
     void sltMessageReceived(const QString &msg);
-    void switchPage(QString moduleName);
+    void switchPage(QString moduleName, QString jumpMoudle);
     void animationFinishedSlot();
-    void showUkccAboutSlot();
+    void initUkccAbout();
+    void onF1ButtonClicked();
+
+Q_SIGNALS:
+    void posChanged();
+
 };
 
 #endif // MAINWINDOW_H
